(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    384691,       6671]
NotebookOptionsPosition[    381787,       6620]
NotebookOutlinePosition[    382196,       6636]
CellTagsIndexPosition[    382153,       6633]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Spherical Pendulum with Fixed Length", "Title",
 CellChangeTimes->{{3.86025561348514*^9, 3.860255623959235*^9}, {
  3.860255667910183*^9, 
  3.8602556696459503`*^9}},ExpressionUUID->"3fdecc31-cf61-4b71-9602-\
fb732812456f"],

Cell["Marvin Zanke & Leon von Detten", "Author",
 CellChangeTimes->{{3.860255672787835*^9, 
  3.8602556833587303`*^9}},ExpressionUUID->"c17b5c93-8911-4db4-b8c9-\
aa1ea5265938"],

Cell["29.04.2022", "Date",
 CellChangeTimes->{{3.860255685213945*^9, 
  3.860255697189713*^9}},ExpressionUUID->"efd0bedd-383f-4c42-8bd3-\
95f7358f5558"],

Cell[TextData[{
 "In this notebook, we create an animation of the spherical pendulum \
investigated in H1) of exercise sheet 5. The problem was tackled in spherical \
coordinates, i.e., \n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {"x"},
      {"y"},
      {"z"}
     }], ")"}], TraditionalForm]],ExpressionUUID->
  "3400914f-397a-4926-996c-d780e601f05a"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {
       RowBox[{"r", " ", 
        RowBox[{"Sin", "(", "\[Theta]", ")"}], 
        RowBox[{"Cos", "(", "\[Phi]", ")"}]}]},
      {
       RowBox[{"r", " ", 
        RowBox[{"Sin", "(", "\[Theta]", ")"}], " ", 
        RowBox[{"Sin", "(", "\[Phi]", ")"}]}]},
      {
       RowBox[{"r", " ", 
        RowBox[{"Cos", "(", "\[Theta]", ")"}]}]}
     }], ")"}], TraditionalForm]],ExpressionUUID->
  "8b0104b8-89d4-47e9-937f-c17e494520f3"],
 "\n\nand solved analytically for the initial conditions ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Theta]", 
     RowBox[{"(", "0", ")"}]}], "=", 
    SubscriptBox["\[Theta]", "0"]}], TraditionalForm]],ExpressionUUID->
  "8b16ea0d-ca27-4c99-a30d-27d051233358"],
 ", ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Theta]", "."], TraditionalForm]],ExpressionUUID->
  "8cf56828-5c9f-4620-9470-90fd6e7a021b"],
 "(0)=0, and \[Phi](0)=0=",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Phi]", "."], TraditionalForm]],ExpressionUUID->
  "8d6bd619-493e-4404-a3d6-a2f70ba99f0c"],
 "(0). This results in a simplified differential equation for \[Theta](t) and \
the fact that the motion is restricted to the x-z plane, \[Phi](t)=0=",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Phi]", "."], TraditionalForm]],ExpressionUUID->
  "74fb494d-542d-4fe9-bb79-edca37b77a19"],
 "(t). Using a small-angle approximation, the solution for \[Theta](t)=\[Pi] \
\[Dash]\[Theta]\[CloseCurlyQuote](t) was found to be given by \[Theta]\
\[CloseCurlyQuote](t) = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     RowBox[{"\[Theta]", "'"}], "0"], 
    RowBox[{"Cos", "(", 
     RowBox[{"\[Omega]", " ", "t"}], ")"}]}], TraditionalForm]],
  ExpressionUUID->"a0e8a91b-f38e-4377-9304-f10ab807204d"],
 ", with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     RowBox[{"\[Theta]", "'"}], "0"], "=", 
    RowBox[{"\[Pi]", "-", 
     RowBox[{
      SubscriptBox["\[Theta]", "0"], "."}]}]}], TraditionalForm]],
  ExpressionUUID->"7dc9c973-03b2-4d56-bbd1-fee7fccf4ae6"]
}], "Text",
 CellChangeTimes->{{3.860255781207676*^9, 3.860255787980147*^9}, {
  3.860259808943707*^9, 3.860259848396659*^9}, {3.860259884033238*^9, 
  3.860259969399982*^9}, {3.860260123918489*^9, 3.860260556272681*^9}, {
  3.8602606329873466`*^9, 3.860260650405796*^9}, {3.8602608335963182`*^9, 
  3.8602608658170977`*^9}, {3.860262711718951*^9, 3.8602627760537157`*^9}, {
  3.8602628088660717`*^9, 3.8602628428933897`*^9}, {3.860320050221986*^9, 
  3.860320070175446*^9}},ExpressionUUID->"612daef6-112f-4f9f-a173-\
f42955c48a1a"],

Cell[CellGroupData[{

Cell["Definitions", "Section",
 CellChangeTimes->{{3.860260658044477*^9, 
  3.860260664569789*^9}},ExpressionUUID->"c3bd4301-8b5f-417a-95d4-\
b0b9d4dea1fd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Reconstruct", " ", "the", " ", "cartesian", " ", "coordinates", " ", "of",
     " ", "the", " ", "pendulum", " ", "from", " ", "the", " ", "obtained", 
    " ", "solution", " ", "in", " ", "spherical", " ", 
    RowBox[{"coordinates", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "t_", "]"}], ":=", 
     RowBox[{"r", "*", 
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "t", "]"}], "]"}], "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "t_", "]"}], ":=", 
     RowBox[{"r", "*", 
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "t", "]"}], "]"}], "*", 
      RowBox[{"Sin", "[", 
       RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"z", "[", "t_", "]"}], ":=", 
     RowBox[{"r", "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "[", "t", "]"}], "]"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.860260672789164*^9, 3.860260704702405*^9}, {
  3.8603201038053303`*^9, 3.860320104920257*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"274d2242-5ff7-4b69-8807-54da9078f407"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "Restrict", " ", "the", " ", "motion", " ", "to", " ", "the", " ", "x"}],
      "-", 
     RowBox[{"z", " ", "plane"}]}], ",", " ", 
    RowBox[{"i", ".", "e", "."}], ",", " ", 
    RowBox[{"\[Phi]", "=", 
     RowBox[{"0", " ", "constant"}]}], ",", " ", 
    RowBox[{"as", " ", "explained", " ", 
     RowBox[{"above", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Phi]", "[", "t_", "]"}], ":=", "0"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.86026072707535*^9, 3.860260750577772*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"b02aef6a-50b2-4e7a-be2c-2ff14b57e680"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "found", " ", "solution", " ", "for", " ", "the", " ", "polar",
     " ", 
    RowBox[{"angle", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Theta]", "[", "t_", "]"}], ":=", 
     RowBox[{"\[Pi]", "-", 
      RowBox[{"\[Theta]P", "[", "t", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     RowBox[{"\[Theta]P", "[", "t_", "]"}], ":=", 
     RowBox[{"\[Theta]P0", "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Omega]", "*", "t"}], "]"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.860257893773799*^9, 3.860257965651827*^9}, {
  3.860260716061021*^9, 3.860260766260601*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"cca295d8-9c14-41fc-b9a2-799da4acc9ea"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Constants", ";", " ", 
    RowBox[{
     RowBox[{"chosen", " ", "arbitrarily", " ", 
      RowBox[{"here", ".", " ", "Feel"}], " ", "free", " ", "to", " ", 
      "modify", " ", "them", " ", "and", " ", "re"}], "-", 
     RowBox[{"evaluate", " ", "the", " ", 
      RowBox[{"notebook", "."}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"r", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Omega]", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Theta]P0", "=", 
     RowBox[{"\[Pi]", "-", "\[Theta]0"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Theta]0", "=", 
     RowBox[{"\[Pi]", "/", "2"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8602607921888657`*^9, 3.860260815465598*^9}, {
  3.860260871948002*^9, 3.860260881052919*^9}, {3.860262086391963*^9, 
  3.860262092060877*^9}, {3.860320121067333*^9, 3.8603201660161743`*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"3639b5fc-705a-489f-a6dd-c7133b3c17fc"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots", "Section",
 CellChangeTimes->{{3.860260920420759*^9, 
  3.86026092739333*^9}},ExpressionUUID->"a44e2a30-f0b8-4dba-bd92-\
9caa2e09d3ef"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"The", " ", "2"}], "-", 
      RowBox[{"sphere", " ", "with", " ", "radius", " ", "r"}]}], "=", "1"}], 
    ",", " ", 
    RowBox[{
    "which", " ", "we", " ", "will", " ", "combine", " ", "with", " ", "the", 
     " ", "pendulum", " ", "into", " ", "a", " ", "single", " ", "graphic", 
     " ", "in", " ", "the", " ", 
     RowBox[{"end", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Sphere2", "=", 
   RowBox[{"SphericalPlot3D", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]", ",", "0", ",", "Pi"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Phi]", ",", "0", ",", 
       RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"White", ",", 
        RowBox[{"Opacity", "[", "0.1", "]"}], ",", 
        RowBox[{"Specularity", "[", 
         RowBox[{"White", ",", "10"}], "]"}]}], "]"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", "15"}], ",", 
     RowBox[{"MeshStyle", "\[Rule]", 
      RowBox[{"Opacity", "[", "0.1", "]"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.860257486744556*^9, 3.8602575770264673`*^9}, 
   3.860257631263026*^9, {3.86026092924727*^9, 3.860260991840432*^9}, {
   3.860261137262053*^9, 3.860261148155451*^9}, {3.8602621231696987`*^9, 
   3.860262138935422*^9}, {3.860320173159439*^9, 3.8603201992463408`*^9}, {
   3.8603203837068233`*^9, 3.860320387110567*^9}, {3.8603217405181437`*^9, 
   3.860321740745678*^9}, {3.860321785215767*^9, 3.860321799980133*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"0503829a-4721-40c5-ba90-5e7ede3edfcb"],

Cell[BoxData[
 FormBox[
  Graphics3DBox[{{GraphicsComplex3DBox[CompressedData["
1:eJyFWHtYjdkertyZM9E4uV8PBrl7jks1++NIuRzEMELul3REYsZxq3RcxsiE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      "], {{
        {GrayLevel[1], Opacity[0.1], EdgeForm[None], Specularity[
          GrayLevel[1], 10], 
         StyleBox[GraphicsGroup3DBox[
           TagBox[{Polygon3DBox[CompressedData["
1:eJwtlEtIlVEUhfc2NTUtyIEWqWla10grCjWvj1tqWWaaPRWECIRGCk1slNA0
R0KjhCY5FAqCsvc7g5rUIKlBD6JEJIsaFCW0FnsNPva95z9nP9c5pSeHegbT
zGwYLAF3QbmbtcKeAutABsjHWi5sN/gOcsAOMCnL/4WgBmCrHQWXQR7YAg6D
LDAKkiAbNIMhsAysBRdAumJug5My2HugFr/3wB6hLw/f73RuPfjHnEEF6Aft
yvk2+AxawAfwAHSCIsVjrDGd5f5D6gNzXoU4j2F7wFtwXf5Z0wbtIdPgGOgD
xRY9Klce9HlVPeN6CXvgETsD9hbsTtYH6vG/DnYl7CPYLtXHOln7J9AImiz2
Tarnu8Fr0AYm9J3re5knfO2Dfa6cE/o+oD3vwX2wn/2WD86lRbUfBA2aH2e3
GfSCperxOdXYofpztV7hEX857EPYA+rRuHrGmc4od+Z3UWdfghugUvNJefSM
cc4qFrUzqDzp97TyoY52qWdrPHJiXedVQ5ZirVBu1EaJx5lFzZda+mGh53r1
iFovVY4dypNaviafxZox1xvg76ZmWuXR60bN66/mfMZi7rxzd0CZhz7ps9pD
4+nykwILqpn5FHnMq1M5/bS4I+S3xb1pw54nFrodsdB8JvgmH6zto3rC3FZr
P7XP2HPKZdZCh9Qu79u8vr+xuAfUOGfT5NGDYe3jfPkGXLJ4BzZ5xGG8rxZ6
oLYLPGadUN5jmu+4cslTbzOlAWpzu4dm2Ot8abvQQxuV2jMqbTwDryz0Oi1/
vAOcfbaHTp+CF+C4hdZPWLyBzL/OY17s7VaPfpMJ6YL+N3qc/aXeJjXjP/KR
hu9TFu/cgHSQo7l/sXhj+d5e0YyS2p9SbgmPe/MfEOh7cA==
              "]], 
             Polygon3DBox[CompressedData["
1:eJxNlnmw0FMUx8+vkqW072l9bVpULy2vlZQlxthirI3KsyUMMdZBlK3N0oKi
opRkhPxhxjKGiSIR0RQpW3mWVK+y5fuZ823GH5+553fPvfd37rnnnnPbjL72
rPFVIuJtUU00KiIaiHLJl0fKC9TWi+y7X9RS3+lqDxXfi+/EdeJ6+qSrLi6U
fJF4R2wRXUV1sdxzGNtQnCqO8vgLRCvJM9XWEEP5r76PFDVFXXGn+pqovULt
IaK35GMBWZRJ7ieaSm4mXnAfcgPRS3JJ5Hz297zXYG598bOoEDeJCWKeOFr6
bmrriDaSZ6udJVpL7i6OET31XSraSz5Z7cXiEtFJ33PVPiXOEx3Fs2Ih+5eu
i3hAcl0xJtLXrFlqn38lPhfrxZfieOluU9vY9h2n79ZqW+BHMazIMRO8hw/F
Kv/3A7FGvG9bVnsP7GWmfb/aulWey/k8KZ4Qm8VG8YVtwrYORe6ZvY5i/2KD
x2y0zdj+mTjRa7DWHLFJzBd/eu/4YLZ93FltbeJG8oORPuri2GrpWCFm6ui7
hjhC1HaM1HRfHfehO1ycovFn20f45max0mc+wT59g7iS/mq1VWzjHNuCTVWk
W6p2iSgkf+0x6Lp4LD4Z5TkDxbeR8dHDc5Y47sJrseaQyJj/VSyLjNtfmCfd
IrXP4Rev91CkT7o69odL7hV5B0r1vThyTk/fhT6Sm0TeCWKZmJ7r2FzsOeWO
N2JyoeOQu1+m9kXbhG3E+jneS0+f3V9irM+wwv7cIUZax5j9oq94NDJHkBtq
iVfEEH03V9vIe2bv3NVxjpsp4uHIfa51XBLLHzsOp4mpjrNt9vcgsdUyfaW2
d5H7B9unJ+jfd6i9XQy1TN+ZaqtG5rtPxTox2WMYyx3knk1S+4ntus/yatu4
1vPWuA/dYtuz1bZsc18927glMqaIJXJm1SLj5Eo1V0WeTQ/nnQU+O3Iauazc
upE+p+7WMYZYaBsZ26zJWsR4tSJjMty/3r6cYt9/E3lnN9muze47LTI3cM+n
+ww4C+7+DPehaycecd8G+3CdfTHJPlvrs7zXvsbn1Jbz3YfuIzFRrBA/iTPE
y2K7Y4jYuVHsETtFf7FbvCR+iKw5yz12u9dgrR/9zdwbIuP2NfFqZJwTyyvd
t8Prcg+I09/EALfXiPGW0Y1z367Ie/u7+MMgl9nOSvfttO3EZbci79NlYl/k
ubHOXvFvZI59XfxjP+/1OtNMpdeaat0u/6PS57DP/dN9NiXum+E5e+y7KWa3
98kd5B4/I56OzCsHxN+2CdtmucU2aspsjzmoO+A+ciM5ktww32vu91oHrKOm
UCs6FplTya3UznMj45y7QD7rTA2OrNGPicOKzDHkmscj6yN96MhvjUWnyJp4
t2ip7xbirkhdQ7+BeAtRi0qKvI/k+Hcj3yTUGWKQukJc3hNZ93kbEb/EOe8W
/tsqsm5hU/3/1aURkbV1hPfIXlmzrsfU97+xgTrdtkhbsZncSQ5F367IXIGN
7exDfMcbhPzbz7E01mfC2XSIrDfce2oRbx9yTIX9S22kRg4u8p5w16i7zV0/
eAuNjqwjzYqsq7xxyOXcsRWeO89zGMPYJvYr+Yo3WNMi9ax1aeRbsKXrA/Wd
Ok6OIA9Qx/EpviV31HRtRzfRZ4Ev3ox8a3b1mIN5hrWGF5nDyd28AwaJWyPf
orxJeU+xh8E+N+pzX2qo6zY6xvDWam7dW5Fvmz4eh0xd5l1JHaJO83bpZpDH
+DyWeF5vn0P/IuskdbvMtmHjQHFLZC3u53HLHDe8a9r7jiyzjrnU0QHeI3vj
jf5epA+G+cywf6lj4STxHwevVMc=
              "]], Polygon3DBox[CompressedData["
1:eJwt0blOgkEQwPFdjlIKCkVR8ApBC3wAISpobDwiFXbqAwiBRhsl8EDQqZze
xkRNoPJI1EJQ34L/5Jvil5kh3+7MDlMH2fShyxgThBdVtLCKPiqYtsZMIowG
dQpdPCCDJ3Twj19s4wZ/uMUo5/aJe9jRe5t6zw96eMEjojjHM+Y5N4co7rVX
gnwRy+Q1xMmviT7iEPzW6S9nZb5dLCBmnO9kvgLy2NL+8qYkssjhAi7OW3i0
V9A670iT32GMfBYz1tlPU3d2iS984hubuoMU3ySxpnfI7HK3G16sUB/reySv
40hnkffmdL4lhKjHsaH9JsiLGqXfFU51jyP8NoyA7JL6DO94wwciGqV+RRvr
KOt/IGdOUMIACWs/aQ==
              "]]},
            Annotation[#, "Charting`Private`Tag$1208#1"]& ]],
          Lighting->Automatic]}, {}, {}, {}, {}}, {
        {GrayLevel[0.3], Opacity[0.1], 
         Line3DBox[{24, 1, 159, 160, 161, 17, 137, 138, 139, 8, 180, 181, 182,
           23, 123, 124, 125, 3, 96, 97, 98, 16, 45, 46, 47, 7, 114, 115, 116,
           22, 27, 28, 29, 4, 149, 148, 147, 14, 129, 128, 127, 6, 176, 175, 
          174, 21, 122, 121, 120, 2, 107, 106, 105, 19, 53, 52, 51, 9, 110, 
          109, 108, 20, 26, 25, 24}]}, {}, {}, 
        {Opacity[0.1], 
         Line3DBox[{24, 54, 249, 250, 99, 299, 300, 60, 48, 84, 234, 235, 117,
           321, 322, 323, 81, 96}], 
         Line3DBox[{29, 32, 264, 263, 92, 286, 285, 77, 224, 44, 292, 68, 230,
           229, 113, 317, 316, 65, 261, 107}], 
         Line3DBox[{7, 136, 135, 134, 133, 132, 131, 130, 5, 146, 145, 144, 
          143, 142, 141, 140, 9}], 
         Line3DBox[{47, 89, 210, 209, 208, 207, 206, 205, 41, 280, 104, 35, 
          248, 247, 246, 245, 244, 59, 110}], 
         Line3DBox[{51, 69, 211, 212, 213, 214, 215, 36, 93, 72, 265, 266, 
          267, 268, 269, 270, 78, 114}], 
         Line3DBox[{16, 158, 157, 156, 13, 164, 163, 162, 18, 167, 166, 165, 
          10, 173, 172, 171, 20}], 
         Line3DBox[{98, 283, 282, 83, 119, 86, 304, 303, 50, 227, 226, 62, 
          101, 56, 314, 313, 26}], 
         Line3DBox[{19, 168, 169, 170, 11, 150, 151, 152, 15, 153, 154, 155, 
          12, 177, 178, 179, 22}], 
         Line3DBox[{105, 256, 257, 258, 63, 111, 66, 287, 288, 289, 42, 220, 
          221, 75, 90, 30, 318, 319, 27}], 
         Line3DBox[{108, 237, 238, 57, 240, 33, 305, 306, 102, 276, 277, 39, 
          200, 87, 296, 297, 45}], 
         Line3DBox[{116, 233, 232, 80, 275, 74, 295, 294, 95, 255, 254, 253, 
          38, 219, 71, 311, 310, 309, 53}], 
         Line3DBox[{25, 312, 55, 251, 100, 301, 61, 225, 49, 302, 85, 236, 
          118, 324, 325, 82, 281, 97}], 
         Line3DBox[{28, 320, 31, 262, 91, 284, 76, 223, 222, 43, 291, 290, 67,
           228, 112, 315, 64, 260, 259, 106}], 
         Line3DBox[{46, 298, 88, 204, 203, 202, 201, 40, 279, 278, 103, 307, 
          34, 243, 242, 241, 58, 239, 109}], 
         Line3DBox[{52, 308, 70, 216, 217, 218, 37, 252, 94, 293, 73, 271, 
          272, 273, 274, 79, 231, 115}]}, 
        {Opacity[0.1], 
         Line3DBox[{120, 187, 261, 259, 256, 168, 309, 308, 69, 140, 59, 239, 
          237, 171, 313, 312, 54, 159}], 
         Line3DBox[{125, 323, 196, 281, 283, 158, 297, 298, 199, 210, 136, 
          270, 194, 231, 233, 179, 319, 320, 32, 149}], 
         Line3DBox[{6, 44, 43, 42, 15, 95, 94, 93, 5, 104, 103, 102, 18, 50, 
          49, 48, 8}], 
         Line3DBox[{127, 193, 224, 222, 220, 153, 294, 293, 72, 130, 126, 280,
           278, 276, 162, 303, 302, 84, 180}], 
         Line3DBox[{139, 60, 225, 227, 167, 306, 307, 35, 146, 36, 252, 255, 
          152, 289, 291, 292, 190, 176}], 
         Line3DBox[{14, 92, 91, 90, 12, 275, 272, 267, 133, 207, 202, 200, 13,
           119, 118, 117, 23}], 
         Line3DBox[{147, 263, 262, 30, 177, 80, 273, 268, 134, 208, 203, 87, 
          156, 83, 324, 321, 123}], 
         Line3DBox[{17, 99, 100, 101, 10, 240, 242, 246, 143, 213, 217, 219, 
          11, 111, 112, 113, 21}], 
         Line3DBox[{161, 250, 251, 56, 173, 57, 241, 245, 142, 212, 216, 191, 
          311, 170, 258, 185, 315, 317, 122}], 
         Line3DBox[{174, 229, 228, 188, 287, 150, 253, 183, 218, 214, 144, 
          247, 243, 33, 165, 62, 301, 299, 137}], 
         Line3DBox[{182, 235, 236, 86, 164, 39, 201, 206, 132, 266, 271, 74, 
          155, 75, 284, 286, 129}], 
         Line3DBox[{121, 316, 186, 260, 257, 169, 310, 70, 211, 141, 244, 58, 
          238, 172, 314, 55, 249, 160}], 
         Line3DBox[{124, 322, 325, 197, 282, 157, 296, 198, 204, 209, 135, 
          269, 274, 195, 232, 178, 318, 31, 264, 148}], 
         Line3DBox[{128, 285, 192, 223, 221, 154, 295, 73, 265, 131, 205, 184,
           279, 277, 163, 304, 85, 234, 181}], 
         Line3DBox[{138, 300, 61, 226, 166, 305, 34, 248, 145, 215, 37, 254, 
          151, 288, 290, 189, 230, 175}]}}},
      VertexNormals->CompressedData["
1:eJx1WXk4ldv3J5WiJJVIUhGFUkqho0WSVCqlUUkSGkQyNBkqQ0WFTCGphEQk
MmapRIbIPGQ6ODjOObjqatbvXO8+v+fLc69/3sfufZa99vpM+22Bue3OY+P4
+Pj0+Pn4BLjPl6l2i7G1FlZkGxt8+Of5bZPelQgWpJP1lWR9ObWOqWRdlVpH
sg4vR7+PKuR9vpGfAXwjGxra5/iMtqxjSEi74AlN4Zbwe5ZLPfl3Pj7Nl3NZ
x/04uE6x7n7U+XY48HCv7Jv5vWj4Q8mlZq0fTZ68P+fTJrXrSoG0tdT7oD36
fVj6IPLjUZFwWsmNH/oeD9/k/sUpy4qK6gL3imViEdxnDN/3Uetu1DqmKQ6P
rA9S6+hC1q+++TOyPkDWyfswUPvNPEQpNVd3MrUvsh/MsC4feS9v0qzMLsso
miups7hn+cqH3H0GmXhGJJ5vx+LL3/hiuL8L7Kbq6FB1gJwDpJM6Ky98Vz59
OpbG+7uKpE4gVQeKqDr/X5+3zqt/5ODPkfp6pD5vn7z3g8l+eHW6D//+t74g
9UdghUN9I3jZO1p6cp9PFyctH3zDBKVLM9Wjb7fARM9zEuncZ2W1/oH6u90w
jbZ2nN/3NjBx3e0axn36Ce5WSV3MAB++wf03+ejw/vyhxhA+Opb8ufXJWZqB
bdIRu85Ft0BueLO2T3QL6tfOuLXLtxsFu9Z7XWQ2gklw7CJfZiNmx3m9Fcli
4lVhqQb9S+lgqOT+ft3BTrTTyBGacbUHNzSZH13vWgiWMk6l3Sl0vGGebafD
34shPQG6O50r4HNqwP3+Y804y1ttQswUFq5IadgjpVWN8nnjwg45M8DuTPCy
/dxniorqs5aWTgxffEVURIEO7fn214S4z/FKbqmZszioV684WbG1EnZGuMrL
c5/Lt8pq3DPpQ0a8wDmF+6XQqXP2zoL7pRhY4KTVqdODHw0W+36+2gzXnlw6
x7najFsiNYeNkhuxsvmgAMevEzQPmBf2+HXiSrKfRdR+kLefF2Q/d6n9IG8/
E8h+1lH7Qd5+BvM0143b1YmZ0gzXNUOhtC2a5epe6T2ofaZOJf8DHc963lUt
+OBHa/E9vEQwpBenzWQe3aHaglduzP9T3O5Om8d4pVy3mo0ZWomprOUdwNy4
UjBjKQPl/K0lrYuaIIQWZN1m3wHrGI/15th04xTNULeQ51VwelHwlkq1Dkg8
tg+HJZn4WNXR+N7nt+BRcEwlWLoFXxQ5N0rQwmlJxRcvmtHYsNuiQygjj46/
Qm6JvJn6gOaS8OVn7v1e2N3X5M0x6MSTpwynnNgbTbu++fKfH7k9oBOk0tHL
3Y9fZsIidQUm5JkNiA4sf4s/7WlH/9mPI9S6inl3g8PWiV9VV1Vh+7sVs6q4
+7m6Sl/r/UYGdOvw67adaUJlsaHxBvcqgCH5UGPB2mbokw38Ii7Ggihfxz/+
PYVgumj8s65QOkiKBlrVTumFC6cuiAbJZMDNTzaec7Z0Qgcnt6v0Vg+I15mV
vZXNh73i9c9rIpngpMY/e9CtHZK2rS7RXF0NrrTQQCULFqi+Hjj/VrUR6iuE
byw51wyCqz8stwhhwSNtPzMNgRKI7Suti3hehUYwaHpy/XtgG/UMb6/lwDil
DfkDN0vQ3/2gQ+yOeuhbNMR6XsQGOfmEsOW0HBw8crbmRCUddGXXrYjd2ws+
hBdbKF7AGcKLTYQXFhQvwIfwIpTwYoDiBfB4YcPwkNBZn4UuSWreH1e0Q6Hi
5V7Teb1oeVf1S5BRMS55/fIRx6EBrlvliTEi2CjzabqYyeYqdJLUaqmbVQy1
6rQorzIOVqh/nZCl1gLZH4eTNnqzQE8/YV5o/HtMti0XH2dRA0c6W4+9cWeB
WcuhM0te1+ODfa6aS0UK4OCOLFPZeiaEjfe81yTcjqqEXw0Uv5DHrxDCrw8U
v9Cb8Gv7aH6hOuGXI+nLleoLC0hfx0lfylRfOLav81RfyOurjPSVQ/WFG0hf
iaSvo1RfaEr6Cid9HaL6wrukL0WCw24Kh8ghOIwYjUPk4dB+NA6xk+CQh5+t
FH6Qh58JBD+3KfxgP8GPMsHPXxR+kIcf0dF4RmeC54TReMaVBM81BM+TKDwj
D8/upvcf9+fk5T7dSekQT3+sDmsISex6lRsrSukQT39+7LNW3NqSkbvGrmdE
h6SJ/uR0K0mzT/ejpeq1ZtPbCTQTtrNR0M9CfHUo6pT0Ew4+WLy/o+ryE9rs
ko83tk6oxw9+84PsE3txb1b0i+ojj2kl1rYn5iTQkedf1yj/Qp5/KRL/EqT8
CyuIf4mM9i/k+RcralhL80NG7lzZET0Dno7N2XLNJUzrVe648SN6Bq5Ex/w+
uyxwTMvLBfcRPQOejv16clzNzLkXd8snzr+VEk8z+Evyd9IvOgQt3cfSduag
y9L77LuzE2ltrduXTB3i+rbGyzblg/14sLTL28j8Gc27tTnH/lwR+BI/LaD8
FIqJn9KJn2ZTfgo8P51E/HQ/5afA89MxOg88nQ8lOq9F6TzwdN52tM4DT+cP
vAkfmXs8NXfYSuZ+8qDayNxjqLlDK5n7xrtW/zt34M0diM77UzqPr4nOfyM6
70TpPDoSnacTnfekdB57iM6Xz52w7p95SVPzQt68kpT8/ndeyJvX1ptX/nde
yJvXs1qXnZqHK+BrvNuK6wF1sGnlzOu6Dmz88yOJlmlSCANDup6PZ9ZD6uza
o7umczAvdcPiQYd0kK4IiPQ9Wg9PzxjJ3bHj4MvKigtBS9LhmUmcqZoFl48X
8j+ZnuGA1OWzbUKKhTDRNU3LSrweN9yx1rOfwYG6dK+54w0rQPmFC7gF1mHg
H8WgB05sECS+r0F835D4fvdk7JRjVOLEGy9KPFZkYm5Q48tVx/vw+TRZPnZi
Eb4qLd3TtLII1/jylSan9aH7AH+xCScTC/0uBb/MrMTTxqFKDjZ9qDAwIBma
24+3f0iuPSeXh3afrU2Z8xJpn3Utlsu+7MO4sBdxjj8qcH72uO3Cu5Jpn3+7
/M4xYuMES2PF/tJmjMVppeZDz2lLbQXCxHK6cdXkyRm3nRgYp9bPluF/QRu3
0vaVg1Qbrls9IflWDAu3GTUvbIlNoaW2coIqt7zD5xdv3qy82Y8nOc7dvYLJ
ND395X2DZ0th8GOdhvDKfpQ03hJ2KvsxTZi+yySQ2+fV2IJQWUYlkH7hlaxB
FJ3b51O5wvKuxCIg/YKTvgw7ndun5rCc6VZOJpB+odO/b16saAt4O9lYVQIb
fptHdF0Jf0j7452r4vS+GtJLA4smbegDNymFa6+ux9GCDsUInM7JA+mA8IiE
zH5YVpdg+bdMEi3k9ytTy4BclFwvPd3sXT/0zirelFyeQhuqvf2x/2Yj/pLa
3xYozQHwyCn5qZxGOzUvecfD5C7clGk577ZfF/zabn021SqN1jf8ipUXyMGw
usR2tnU9OP58+mK/bwot+9/xgzL/jh9sIPhZOho/+PbC0nNWc4rworr899dV
7XBcO79k5xwmbt22QXwFrQHn95YFvB73CX661iudkelFpkyTldCWdnwgXafN
mFwKmunfRV0MmViqydF9W8Vdj2oe2sutZ03qmFe25ReM+4Q/LoZ5KXHr8eoE
/H3T6MvkUhyYaTk0iVtPg9T5UD28Xn3RW5itwj7qfLgL79jYlp453AWPYsTs
5y6ugvaJ9h+nhDCw3yDm2MQQBuwV2Xzp2bEmuCqXWKmq34n60lcylfQ7IZHw
9MtongLfT4qnHMLTNIqn8JbwVIrwNIHiKZSQviJIX+R8wIz09ZX09YvqC/xJ
XxzS11qqL3hDzvnC6HMG3jnLjD5n6Blzzrw6TxkLU7vTm+B6mMnSVPVO0E1I
E0lU78QzF8J/7r1XBT4KCRZt1xkgv8FzoOE6AxO26FysbnwLIXnx1zwOdMGf
4oYe1wNdGDOmzgaqDpweU0eBqgNxpE7w6DogQnjnNZp3iIR3z0bzDp3H8M6G
6MxHMndJMvcAau7Im3sHmTuHmjvy5u5J5q5HzR0ZRPf4R+seJBHdyx6te3D5
33UPdpHcWEHuZRokN6aT+1cIuX/Ryf3rzpi8bU/y9naSt81J3vYlefseydu9
JG+Lk7ztRHLpJZK3i0gutSW5dCHJ2z4kly4iudSU5O06kkvjRudM4OVMO1JH
juTbG2PqHCH5llfnLcm3r0i+PUbybeyYfGtJ8q0sybH9JMeySY4NJDnWjORY
CZJjY8fkybUkT5aQPClE8mQByZOuAZMMhvnSMHyhcJ7Xjh6UXWIQueZRJ6wu
WfC3yo5mnPHAf1XwuC7c/22FufaEdrhrf+l+dHIJnnz8Ubkgh4nWs6c+Z6bR
YYNapW+jezwYLvRcPe8xCwUNXfxmTGqDR2Q/bmQ/6mQ/8UmC4ZPle/Gai4tH
NKsZfxe6mrADa0Dh1J6s/m0MvJ3OmRac3Yl9RetlzBPqIDxkKd+uU03ocuiE
EXuAiQXGDzbHnKwH92UPlHt08zHlrKin5AkOTgubVnN0Rh3MFrzzRc46HwL3
L8JrM/vwqDVn/X3DKkByDiLkHNLIOehdosXEXKqEy5N8jac95MBxxe73XyXK
ccM3ZfrcvCdwZP2UVPk7fdAW82OBWUQlHlI1DPPRLcPmT35SVYYcuKYhUPio
qBppafsYVip0zFRivJOq7wGT7fMSG+fWoHCfS9zwQSZqMT1PrBajw/3GQHoF
l1dPDzHUVi1MAVXHxaoxS9igOKxneHAKN6ez1/8y1P6AFuMvaL850Atn3z1I
SYlowwyhZUGeCW14subg48SXDICq0JhT/m04ayhoTqVTHlqVqdUoHOuB0F/n
Daq495gujRSrfNdWnGt25GKkeDG6FJ/3UpnFwvUmTWW3sAq/ZeR77IhpwCSZ
pi3VYSycq5iiam7YgHIpbXnuJ4qRE+oUoRHNxvME54vG4FxpDM5rCM4DnFfk
2Lo1oKvAg8ifi4tgEb9W5pqnbNhg9MlM7mYVHi4+6XztYgM0TA058yyRBV+X
7WMeU2hF8RMlFhyrYogvC/BwXcKCA1YTLSNvZeEO/6tPvpa1gPOaQ749DSxc
E7Kjq2xVFp6sr498P1AP7UuvvbxnwMHI09Yhv/+5T25M1chRqoJLjw97OFRx
8NepLpuvHi0AysKGUMNEnapH/q+0azHt9Q0V7fhqCJaSuZ/f14OG+9dNO7GC
jnz5/JOGmM2QXZgVP/NYNwqz3arNy1txP/+zmblFxfile597kEslPjv96tdQ
JwfEt52T+yKSjTaJTzjGvvW4ME1iy0sTDhjlFA4O1WbjdomH2trqLVi5U/+W
+DALNtzcd3hmRjM4Wlgn9ut2g/sHsWmiKm2w+93k29JLqqHpst0XiXc9kLHx
3DlGAB3WTzf/seB7MxhaJFzEfCbc+RRy5aBeHTgQ/kZQ/AUefzvUJhuXSKTB
gXjf6N5MFvDXRM9vv9oKc/f5Xf19sQDHJVisYCj2gtC3d1uNbtAhpmpq9Gv/
T/j3lbnDPje6gL5pz+Cuqe3w/q5HY3ZdBVxVME0PcuHAsamymx8bVMAmg5rK
YaEncPnU+Rsv1fpAgrO6xaq1GpRPfRs8qVKKa9/ZvWL1sOFZ+99WU33qINYr
nSM11IrRmoPC9p09YPvz+8TLx+thkPliSVhhNxae3RmnJN0Ot1d8n8yqrQUB
0Sv1scmFwJ5V1nvgfTNIrnk3Py6FBfU5dUI/i9NBhT9y4o6ZLXA8O6AuRpwN
cp4RajECGfDwUIhIK/eemHjkN6g49EJ4jtH4i7UsHPBKUtO9UAZxuZtV/zz6
hNuIH30c850w/vqmPU4SHRg13SMs1LYZXNxVvMOEGNixM0zAPqsb28UEcvI8
ysBVRmdmxPRO3ONw13iyVgNogVS7eUA72Gi4Tqoo7cIrcft8hNzKwb9MMkY9
rQNyuir5ln7uxtD/+I60Ls4D2Y41YJQYODcuvQ2YdpZ/2Ygzcfd/fF96SPyu
f8z3JcHbqsGfQ9LBY2NLWXEVHY/KSE77at2LD5Ru9sdx/+79p5pDSSotKMo0
MtwjykZbtd5PE+wKYZC+V/44V4cHswL0Hyew0PHViyj+7yykz/5dosNswKpY
KXmWYgVKSrG/bPXpxvi8syI3DDsw+a/pVy+mVuHfQbopbx3a8O0HRtSgERPV
T5cmP1KuQWU373NpPcVI6zOTrfPmYMv4WtNjcdUY+C3SLbjtNTyuiDwbZteH
h7wzb4ffrcA04o9viD8aE3/c+0tn5pbvdLwSVuWt+Z6bG+yPK4lataHR1hNR
AdycUZ27cK9NOBM1F/7JO53XhvxqC9I6vYLhw2n14LYpbIwu4zPpym/Bh8Rn
LYjPHiU+K03005rSTwwm+nnn1H3nlIEufJfsL+WlVY77cn8dn9jVCeHjV6Xd
NfjnflsgYxjZggnFW63XK3RBwwJWu6djL8rMNJ2lN4l7f9yW+kNeoRXSSM4J
HvOdeSK5b6qT++YOct/0ER12WulRA/J+OcvDHrXhdi1BvZT5TIiXG5r44lQ5
/Jk9wWp2XAdmOA7GOv7phvIjATvdFjbAaalqi1U32lFqzezoosYu2Ev0cxel
n+hE9LNPb/baN6uKUWSJwMqD0lWok6piO6Oag0O5E3CeQxaaibw3suqox8Jz
PrYBWzjo8h85KsHG/oqAfhXOG/GXRthj4/igIoiFBjLtsSISrTjFtk8mQ6wE
isT9k81kuXmM+IjsmNw1xnegj/iOIvGXw2O+f0YQXndRvMZYwmuM4/Mra+7G
8BH+fsBfEyTkvfk7sUFacK7i5g58FsWMeP25CU+aZ6zWmMTAyMW6m50Eq+H6
a7ND0kU9qB3cWdsQTAfj/RGfEkKbQcy4RXX+5m4UUSve4rOqDdYQHd5B6TCG
Eh12nrMzu7goC++INT8zDq8HbwfNrX77OSB8cdN11bhivPvRLPb5zUqQWav/
116uX+wivrCN8gXg+QLPN89Rvok839QyTKu1u9aKe0Z8swjNNl1qDZViwbK7
s8RwuAp7q6dbZ01vQOnmkjKf5yzw8pvxfMFwG5aP4LYV3HqaZs1Q7IKFwvWa
mNmFYoo+00X3fISNe+YEfx3uhHqC2yUUbmEbwe1kG8o3aZRvcvMG5ZvaT5kr
XCe2gH/kyerlh7thuj79VMW7VnRfaSlRxr3XCy3UX1LW2wNvDnRrfF5Kx9j/
+P4cTHAuR+EcthGcL7b77D8ZGoCv2vXCH8928H8jsXR3Lfd+ZNgzmx5XDsla
s02MH3fA+qd/dxf86oYZRPeuUrrH1UtK9yxXM8+nXSqEwKD8yB+9zfBa54To
bK6+vRB2Uj4YnA5e3/3Fr6u0gNUC1jUhrh6mnexvO6NTDi/youVEMjrwYVJ5
efvf3binaodqjUwDVOm2NbwMbsd2ycze/RVduJLotjGl28jTbd97m/aEJ6eD
mkLkNreZLdx717v9n7k+xd76o+7Ro0KoNqyfXv2+GYN6H1zQeMGChSTn95Cc
z/t/k1mjfQ15vhZE8v9hkv/nkPz/fxZHSWk=
       "],
      VertexTextureCoordinates->CompressedData["
1:eJyVmEGO1TAMhttBrNlwAU7yVlyAIyCx5mo9QpddRppKVJosqip6ytMbUPYg
QHRqR/7STEs2lhPH+X/XdvLeh89fP315aJrmY9s0/+T+SJfX5ylnyKN5GVyX
4S5Wxopem08Vuxn2xMNzZ+ynnYx0gEOGzHeY76EPqv9Zx039veh31X+v+nes
3yDvKsXe7hshJ0gPuUAPat+u8rqd96h+Zd7aBfXTbn4t3xl8Z+CegTsBdwLO
hPjL/h76AF34ygiqW14yOpzTQw6QI/QJ9h7+Osz32Jf9SjzfbPMSz7fbPonn
u82vzZtH5M03tf+1yifER3AFxSXxkfOt/QL7oPY2j27Q75o/gucBfl/Wf8D/
c+FXcFv7Xu0lnrS3+HucMyDfR+yf4N/r+dYuIv8j8j8CxwwcM3DMwJ+APyl+
q4u9g72DvVO+9rwJulfd8pV+d1fd8pUxQp+ge/i7KT7r3yGeDvFMiGdCPBmf
iPhExIf3wtnvQB71OLWGP3mc5cW+dzav8j37f31cxtnvyjw+28d5r5/N0wQ+
R/dwhP8I/xH+WceiB9VtvB3wHOW1jLPvDtaBAx5X4LF8Hfi6Ct+zdeNgf9SH
EvAcvQsi4nnUd2Ucvwt4D7QGR8C5gv9Z+dl7qYP9CPsJ9h7n03+A/bLd08vF
9pOg8Xi/4ZB1eUfIurwTRP+5yqfKezMC9xXfKa9b3pP6F57CZ583887Dny/8
Wby85xfEk3WygOcCXgH7A/YH3f963fO9HMBjgR4OeHng4nuScRqL72r1qTh3
/x13xT6+IzvEoS/qyu4bwWuqrLNPkTfXR8SpFjeP/b6yn7h66APmmS/M89rv
rFwHNl/YT3ro+feCtb+rPb+brIsfWd/Xc55aXgtw815k3jPPF+AK8Bfgj304
15Hdx3uddZ5/B9t11j3fZ4wj4z4Ucduvm1qd5fvC6uyrrO+yz9rz2HfL77Yf
9xF+y76x3w9Y5/ydzLqv9WnWEf/3qNUp+bIvHfUp1jPrvKz7Wh7I+n7e8H+f
su7265Z9Idc9z7X2GedfmzmPoA==
       "]], {}}, {}},
   Axes->True,
   BaseStyle->{FontFamily -> "Arial"},
   DisplayFunction->Identity,
   FaceGridsStyle->Automatic,
   ImagePadding->Automatic,
   Method->{
    "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}},
   PlotRange->{{-1, 1}, {-1, 1}, {-1, 1}},
   PlotRangePadding->{{0, 0}, {0, 0}, {0, 0}},
   Ticks->{Automatic, Automatic, Automatic}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.86025749160182*^9, 3.860257577656052*^9}, 
   3.860257631851459*^9, 3.8602609637732162`*^9, {3.860260994339814*^9, 
   3.860261015154759*^9}, {3.8602611405274477`*^9, 3.860261148725713*^9}, 
   3.860262160529529*^9, 3.86026223972544*^9, 3.860320218254858*^9, {
   3.8603203845525017`*^9, 3.860320387512723*^9}, 3.860320525945456*^9, 
   3.8603207350986633`*^9, 3.8603211581248007`*^9, {3.860321766403286*^9, 
   3.860321812811158*^9}},
 CellLabel->"Out[11]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ExpressionUUID->"bef4810d-2f80-4765-ac33-25220af98794"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "If", " ", "your", " ", "computer", " ", "has", " ", "trouble", " ", 
     "displaying", " ", "the", " ", "animation", " ", 
     RowBox[{"(", 
      RowBox[{
      "that", " ", "is", " ", "if", " ", "you", " ", "experience", " ", 
       "lags"}], ")"}]}], ",", " ", 
    RowBox[{
    "you", " ", "may", " ", "use", " ", "this", " ", "sphere", " ", 
     "instead"}], ",", " ", 
    RowBox[{
    "which", " ", "will", " ", "render", " ", "the", " ", "animation", " ", 
     RowBox[{"faster", ".", " ", "To"}], " ", "do", " ", "so"}], ",", " ", 
    RowBox[{
     RowBox[{
     "you", " ", "have", " ", "to", " ", "put", " ", "the", " ", "above", " ",
       "2"}], "-", 
     RowBox[{
     "sphere", " ", "into", " ", "a", " ", "comment", " ", "by", " ", 
      "\"\<\>", 
      RowBox[{"(*", " ", "...", " ", "*)"}], 
      "\"\< and remove the comment from the 2-sphere below. \>"}]}]}], "*)"}],
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Sphere2", "=", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"Blue", ",", 
       RowBox[{"Opacity", "[", "0.1", "]"}], ",", 
       RowBox[{"Sphere", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], 
      "}"}], "]"}]}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.860261481642796*^9, 3.860261488763153*^9}, {
  3.860262111641079*^9, 3.860262116842946*^9}, {3.8602621644122887`*^9, 
  3.8602621645407333`*^9}, {3.860320372539124*^9, 3.8603203764596043`*^9}, {
  3.860320444411853*^9, 3.860320511375729*^9}, {3.860320543994831*^9, 
  3.8603205656181593`*^9}, {3.86032099845643*^9, 3.860321017582632*^9}, {
  3.860321099148432*^9, 3.8603211230123158`*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"8b83da87-b3a8-4605-a859-d3a4ab22294d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "ball", " ", "of", " ", "the", " ", 
    RowBox[{"pendulum", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ball", "[", "t_", "]"}], ":=", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", "t", "]"}], ",", 
         RowBox[{"y", "[", "t", "]"}], ",", 
         RowBox[{"z", "[", "t", "]"}]}], "}"}], "]"}]}], "}"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.860261170560774*^9, 3.860261197504876*^9}, {
  3.860261228221056*^9, 3.860261238219392*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"e32e07db-bcfa-428f-84b8-ad2e7e193752"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "thread", " ", "of", " ", "the", " ", 
    RowBox[{"pendulum", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"thread", "[", "t_", "]"}], ":=", 
    RowBox[{"Line", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", "t", "]"}], ",", 
         RowBox[{"y", "[", "t", "]"}], ",", 
         RowBox[{"z", "[", "t", "]"}]}], "}"}]}], "}"}], "]"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.860261215864058*^9, 3.860261220244624*^9}, {
  3.860261251578271*^9, 3.860261257341823*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"0496fa40-cc3c-4b14-af91-a68a47c6cf41"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "track", " ", "of", " ", "the", " ", 
    RowBox[{"pendulum", "'"}], "s", " ", 
    RowBox[{"ball", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"track", "[", "t_", "]"}], ":=", 
    RowBox[{"{", 
     RowBox[{"Green", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{"Function", "[", 
          RowBox[{"Evaluate", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"x", "[", "#", "]"}], ",", 
             RowBox[{"y", "[", "#", "]"}], ",", 
             RowBox[{"z", "[", "#", "]"}]}], "}"}], "]"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "t", ",", "0.025"}], "]"}]}], "]"}], "]"}]}], 
     "}"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.860261292566422*^9, 3.8602613249464817`*^9}, {
  3.860262187566127*^9, 3.860262220738494*^9}, {3.860320593504472*^9, 
  3.860320594117154*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"0cf089cf-6620-4f9a-99d1-5491cac6ced5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "complete", " ", "spherical", " ", 
    RowBox[{"pendulum", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Pendulum", "[", "t_", "]"}], ":=", 
     RowBox[{"Graphics3D", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", ".025", "]"}], ",", 
          RowBox[{"ball", "[", "t", "]"}], ",", 
          RowBox[{"thread", "[", "t", "]"}]}], "}"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Axes", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", "False"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "The", " ", "complete", " ", "spherical", " ", "pendulum", " ", "with", 
     " ", "a", " ", "green", " ", "track", " ", "left", " ", "behind", " ", 
     "the", " ", 
     RowBox[{"ball", "'"}], "s", " ", 
     RowBox[{"motion", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PendulumTrack", "[", "t_", "]"}], ":=", 
     RowBox[{"Graphics3D", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"PointSize", "[", ".025", "]"}], ",", 
           RowBox[{"ball", "[", "t", "]"}], ",", 
           RowBox[{"thread", "[", "t", "]"}]}], "}"}], ",", 
         RowBox[{"track", "[", "t", "]"}]}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Axes", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", "False"}]}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8602610413186617`*^9, 3.8602611175213842`*^9}, {
   3.860261234907454*^9, 3.860261250265136*^9}, 3.860261289811047*^9, {
   3.860261327263527*^9, 3.860261338206728*^9}, {3.860261975965633*^9, 
   3.860262007883922*^9}, {3.860262042778652*^9, 3.860262049711115*^9}, {
   3.860262212290962*^9, 3.860262274954055*^9}, {3.8603205812457113`*^9, 
   3.86032058584435*^9}, {3.860320992530279*^9, 3.860320993474782*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"492b59cb-38fb-4f75-ab57-76c3e1a5dfb3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "initial", " ", "position", " ", "of", " ", "the", " ", 
    RowBox[{"pendulum", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Show", "[", 
   RowBox[{"Sphere2", ",", 
    RowBox[{"Pendulum", "[", "0", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.860261055271345*^9, 3.8602610650276213`*^9}, {
  3.860261125145526*^9, 3.860261131187274*^9}, {3.8602613438941593`*^9, 
  3.86026136086325*^9}, {3.860261506702219*^9, 3.860261543025066*^9}, {
  3.8603206006707706`*^9, 3.860320601047264*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"981ffc55-b631-490a-8609-a87476cce184"],

Cell[BoxData[
 FormBox[
  Graphics3DBox[{{{GraphicsComplex3DBox[CompressedData["
1:eJyFWHtYjdkertyZM9E4uV8PBrl7jks1++NIuRzEMELul3REYsZxq3RcxsiE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       "], {{
         {GrayLevel[1], Opacity[0.1], EdgeForm[None], Specularity[
           GrayLevel[1], 10], 
          StyleBox[GraphicsGroup3DBox[
            TagBox[{Polygon3DBox[CompressedData["
1:eJwtlEtIlVEUhfc2NTUtyIEWqWla10grCjWvj1tqWWaaPRWECIRGCk1slNA0
R0KjhCY5FAqCsvc7g5rUIKlBD6JEJIsaFCW0FnsNPva95z9nP9c5pSeHegbT
zGwYLAF3QbmbtcKeAutABsjHWi5sN/gOcsAOMCnL/4WgBmCrHQWXQR7YAg6D
LDAKkiAbNIMhsAysBRdAumJug5My2HugFr/3wB6hLw/f73RuPfjHnEEF6Aft
yvk2+AxawAfwAHSCIsVjrDGd5f5D6gNzXoU4j2F7wFtwXf5Z0wbtIdPgGOgD
xRY9Klce9HlVPeN6CXvgETsD9hbsTtYH6vG/DnYl7CPYLtXHOln7J9AImiz2
Tarnu8Fr0AYm9J3re5knfO2Dfa6cE/o+oD3vwX2wn/2WD86lRbUfBA2aH2e3
GfSCperxOdXYofpztV7hEX857EPYA+rRuHrGmc4od+Z3UWdfghugUvNJefSM
cc4qFrUzqDzp97TyoY52qWdrPHJiXedVQ5ZirVBu1EaJx5lFzZda+mGh53r1
iFovVY4dypNaviafxZox1xvg76ZmWuXR60bN66/mfMZi7rxzd0CZhz7ps9pD
4+nykwILqpn5FHnMq1M5/bS4I+S3xb1pw54nFrodsdB8JvgmH6zto3rC3FZr
P7XP2HPKZdZCh9Qu79u8vr+xuAfUOGfT5NGDYe3jfPkGXLJ4BzZ5xGG8rxZ6
oLYLPGadUN5jmu+4cslTbzOlAWpzu4dm2Ot8abvQQxuV2jMqbTwDryz0Oi1/
vAOcfbaHTp+CF+C4hdZPWLyBzL/OY17s7VaPfpMJ6YL+N3qc/aXeJjXjP/KR
hu9TFu/cgHSQo7l/sXhj+d5e0YyS2p9SbgmPe/MfEOh7cA==
               "]], 
              Polygon3DBox[CompressedData["
1:eJxNlnmw0FMUx8+vkqW072l9bVpULy2vlZQlxthirI3KsyUMMdZBlK3N0oKi
opRkhPxhxjKGiSIR0RQpW3mWVK+y5fuZ823GH5+553fPvfd37rnnnnPbjL72
rPFVIuJtUU00KiIaiHLJl0fKC9TWi+y7X9RS3+lqDxXfi+/EdeJ6+qSrLi6U
fJF4R2wRXUV1sdxzGNtQnCqO8vgLRCvJM9XWEEP5r76PFDVFXXGn+pqovULt
IaK35GMBWZRJ7ieaSm4mXnAfcgPRS3JJ5Hz297zXYG598bOoEDeJCWKeOFr6
bmrriDaSZ6udJVpL7i6OET31XSraSz5Z7cXiEtFJ33PVPiXOEx3Fs2Ih+5eu
i3hAcl0xJtLXrFlqn38lPhfrxZfieOluU9vY9h2n79ZqW+BHMazIMRO8hw/F
Kv/3A7FGvG9bVnsP7GWmfb/aulWey/k8KZ4Qm8VG8YVtwrYORe6ZvY5i/2KD
x2y0zdj+mTjRa7DWHLFJzBd/eu/4YLZ93FltbeJG8oORPuri2GrpWCFm6ui7
hjhC1HaM1HRfHfehO1ycovFn20f45max0mc+wT59g7iS/mq1VWzjHNuCTVWk
W6p2iSgkf+0x6Lp4LD4Z5TkDxbeR8dHDc5Y47sJrseaQyJj/VSyLjNtfmCfd
IrXP4Rev91CkT7o69odL7hV5B0r1vThyTk/fhT6Sm0TeCWKZmJ7r2FzsOeWO
N2JyoeOQu1+m9kXbhG3E+jneS0+f3V9irM+wwv7cIUZax5j9oq94NDJHkBtq
iVfEEH03V9vIe2bv3NVxjpsp4uHIfa51XBLLHzsOp4mpjrNt9vcgsdUyfaW2
d5H7B9unJ+jfd6i9XQy1TN+ZaqtG5rtPxTox2WMYyx3knk1S+4ntus/yatu4
1vPWuA/dYtuz1bZsc18927glMqaIJXJm1SLj5Eo1V0WeTQ/nnQU+O3Iauazc
upE+p+7WMYZYaBsZ26zJWsR4tSJjMty/3r6cYt9/E3lnN9muze47LTI3cM+n
+ww4C+7+DPehaycecd8G+3CdfTHJPlvrs7zXvsbn1Jbz3YfuIzFRrBA/iTPE
y2K7Y4jYuVHsETtFf7FbvCR+iKw5yz12u9dgrR/9zdwbIuP2NfFqZJwTyyvd
t8Prcg+I09/EALfXiPGW0Y1z367Ie/u7+MMgl9nOSvfttO3EZbci79NlYl/k
ubHOXvFvZI59XfxjP+/1OtNMpdeaat0u/6PS57DP/dN9NiXum+E5e+y7KWa3
98kd5B4/I56OzCsHxN+2CdtmucU2aspsjzmoO+A+ciM5ktww32vu91oHrKOm
UCs6FplTya3UznMj45y7QD7rTA2OrNGPicOKzDHkmscj6yN96MhvjUWnyJp4
t2ip7xbirkhdQ7+BeAtRi0qKvI/k+Hcj3yTUGWKQukJc3hNZ93kbEb/EOe8W
/tsqsm5hU/3/1aURkbV1hPfIXlmzrsfU97+xgTrdtkhbsZncSQ5F367IXIGN
7exDfMcbhPzbz7E01mfC2XSIrDfce2oRbx9yTIX9S22kRg4u8p5w16i7zV0/
eAuNjqwjzYqsq7xxyOXcsRWeO89zGMPYJvYr+Yo3WNMi9ax1aeRbsKXrA/Wd
Ok6OIA9Qx/EpviV31HRtRzfRZ4Ev3ox8a3b1mIN5hrWGF5nDyd28AwaJWyPf
orxJeU+xh8E+N+pzX2qo6zY6xvDWam7dW5Fvmz4eh0xd5l1JHaJO83bpZpDH
+DyWeF5vn0P/IuskdbvMtmHjQHFLZC3u53HLHDe8a9r7jiyzjrnU0QHeI3vj
jf5epA+G+cywf6lj4STxHwevVMc=
               "]], Polygon3DBox[CompressedData["

1:eJwt0blOgkEQwPFdjlIKCkVR8ApBC3wAISpobDwiFXbqAwiBRhsl8EDQqZze
xkRNoPJI1EJQ34L/5Jvil5kh3+7MDlMH2fShyxgThBdVtLCKPiqYtsZMIowG
dQpdPCCDJ3Twj19s4wZ/uMUo5/aJe9jRe5t6zw96eMEjojjHM+Y5N4co7rVX
gnwRy+Q1xMmviT7iEPzW6S9nZb5dLCBmnO9kvgLy2NL+8qYkssjhAi7OW3i0
V9A670iT32GMfBYz1tlPU3d2iS984hubuoMU3ySxpnfI7HK3G16sUB/reySv
40hnkffmdL4lhKjHsaH9JsiLGqXfFU51jyP8NoyA7JL6DO94wwciGqV+RRvr
KOt/IGdOUMIACWs/aQ==
               "]]},
             Annotation[#, "Charting`Private`Tag$1208#1"]& ]],
           Lighting->Automatic]}, {}, {}, {}, {}}, {
         {GrayLevel[0.3], Opacity[0.1], 
          Line3DBox[{24, 1, 159, 160, 161, 17, 137, 138, 139, 8, 180, 181, 
           182, 23, 123, 124, 125, 3, 96, 97, 98, 16, 45, 46, 47, 7, 114, 115,
            116, 22, 27, 28, 29, 4, 149, 148, 147, 14, 129, 128, 127, 6, 176, 
           175, 174, 21, 122, 121, 120, 2, 107, 106, 105, 19, 53, 52, 51, 9, 
           110, 109, 108, 20, 26, 25, 24}]}, {}, {}, 
         {Opacity[0.1], 
          Line3DBox[{24, 54, 249, 250, 99, 299, 300, 60, 48, 84, 234, 235, 
           117, 321, 322, 323, 81, 96}], 
          Line3DBox[{29, 32, 264, 263, 92, 286, 285, 77, 224, 44, 292, 68, 
           230, 229, 113, 317, 316, 65, 261, 107}], 
          Line3DBox[{7, 136, 135, 134, 133, 132, 131, 130, 5, 146, 145, 144, 
           143, 142, 141, 140, 9}], 
          Line3DBox[{47, 89, 210, 209, 208, 207, 206, 205, 41, 280, 104, 35, 
           248, 247, 246, 245, 244, 59, 110}], 
          Line3DBox[{51, 69, 211, 212, 213, 214, 215, 36, 93, 72, 265, 266, 
           267, 268, 269, 270, 78, 114}], 
          Line3DBox[{16, 158, 157, 156, 13, 164, 163, 162, 18, 167, 166, 165, 
           10, 173, 172, 171, 20}], 
          Line3DBox[{98, 283, 282, 83, 119, 86, 304, 303, 50, 227, 226, 62, 
           101, 56, 314, 313, 26}], 
          Line3DBox[{19, 168, 169, 170, 11, 150, 151, 152, 15, 153, 154, 155, 
           12, 177, 178, 179, 22}], 
          Line3DBox[{105, 256, 257, 258, 63, 111, 66, 287, 288, 289, 42, 220, 
           221, 75, 90, 30, 318, 319, 27}], 
          Line3DBox[{108, 237, 238, 57, 240, 33, 305, 306, 102, 276, 277, 39, 
           200, 87, 296, 297, 45}], 
          Line3DBox[{116, 233, 232, 80, 275, 74, 295, 294, 95, 255, 254, 253, 
           38, 219, 71, 311, 310, 309, 53}], 
          Line3DBox[{25, 312, 55, 251, 100, 301, 61, 225, 49, 302, 85, 236, 
           118, 324, 325, 82, 281, 97}], 
          Line3DBox[{28, 320, 31, 262, 91, 284, 76, 223, 222, 43, 291, 290, 
           67, 228, 112, 315, 64, 260, 259, 106}], 
          Line3DBox[{46, 298, 88, 204, 203, 202, 201, 40, 279, 278, 103, 307, 
           34, 243, 242, 241, 58, 239, 109}], 
          Line3DBox[{52, 308, 70, 216, 217, 218, 37, 252, 94, 293, 73, 271, 
           272, 273, 274, 79, 231, 115}]}, 
         {Opacity[0.1], 
          Line3DBox[{120, 187, 261, 259, 256, 168, 309, 308, 69, 140, 59, 239,
            237, 171, 313, 312, 54, 159}], 
          Line3DBox[{125, 323, 196, 281, 283, 158, 297, 298, 199, 210, 136, 
           270, 194, 231, 233, 179, 319, 320, 32, 149}], 
          Line3DBox[{6, 44, 43, 42, 15, 95, 94, 93, 5, 104, 103, 102, 18, 50, 
           49, 48, 8}], 
          Line3DBox[{127, 193, 224, 222, 220, 153, 294, 293, 72, 130, 126, 
           280, 278, 276, 162, 303, 302, 84, 180}], 
          Line3DBox[{139, 60, 225, 227, 167, 306, 307, 35, 146, 36, 252, 255, 
           152, 289, 291, 292, 190, 176}], 
          Line3DBox[{14, 92, 91, 90, 12, 275, 272, 267, 133, 207, 202, 200, 
           13, 119, 118, 117, 23}], 
          Line3DBox[{147, 263, 262, 30, 177, 80, 273, 268, 134, 208, 203, 87, 
           156, 83, 324, 321, 123}], 
          Line3DBox[{17, 99, 100, 101, 10, 240, 242, 246, 143, 213, 217, 219, 
           11, 111, 112, 113, 21}], 
          Line3DBox[{161, 250, 251, 56, 173, 57, 241, 245, 142, 212, 216, 191,
            311, 170, 258, 185, 315, 317, 122}], 
          Line3DBox[{174, 229, 228, 188, 287, 150, 253, 183, 218, 214, 144, 
           247, 243, 33, 165, 62, 301, 299, 137}], 
          Line3DBox[{182, 235, 236, 86, 164, 39, 201, 206, 132, 266, 271, 74, 
           155, 75, 284, 286, 129}], 
          Line3DBox[{121, 316, 186, 260, 257, 169, 310, 70, 211, 141, 244, 58,
            238, 172, 314, 55, 249, 160}], 
          Line3DBox[{124, 322, 325, 197, 282, 157, 296, 198, 204, 209, 135, 
           269, 274, 195, 232, 178, 318, 31, 264, 148}], 
          Line3DBox[{128, 285, 192, 223, 221, 154, 295, 73, 265, 131, 205, 
           184, 279, 277, 163, 304, 85, 234, 181}], 
          Line3DBox[{138, 300, 61, 226, 166, 305, 34, 248, 145, 215, 37, 254, 
           151, 288, 290, 189, 230, 175}]}}},
       VertexNormals->CompressedData["
1:eJx1WXk4ldv3J5WiJJVIUhGFUkqho0WSVCqlUUkSGkQyNBkqQ0WFTCGphEQk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        "],
       VertexTextureCoordinates->CompressedData["
1:eJyVmEGO1TAMhttBrNlwAU7yVlyAIyCx5mo9QpddRppKVJosqip6ytMbUPYg
QHRqR/7STEs2lhPH+X/XdvLeh89fP315aJrmY9s0/+T+SJfX5ylnyKN5GVyX
4S5Wxopem08Vuxn2xMNzZ+ynnYx0gEOGzHeY76EPqv9Zx039veh31X+v+nes
3yDvKsXe7hshJ0gPuUAPat+u8rqd96h+Zd7aBfXTbn4t3xl8Z+CegTsBdwLO
hPjL/h76AF34ygiqW14yOpzTQw6QI/QJ9h7+Osz32Jf9SjzfbPMSz7fbPonn
u82vzZtH5M03tf+1yifER3AFxSXxkfOt/QL7oPY2j27Q75o/gucBfl/Wf8D/
c+FXcFv7Xu0lnrS3+HucMyDfR+yf4N/r+dYuIv8j8j8CxwwcM3DMwJ+APyl+
q4u9g72DvVO+9rwJulfd8pV+d1fd8pUxQp+ge/i7KT7r3yGeDvFMiGdCPBmf
iPhExIf3wtnvQB71OLWGP3mc5cW+dzav8j37f31cxtnvyjw+28d5r5/N0wQ+
R/dwhP8I/xH+WceiB9VtvB3wHOW1jLPvDtaBAx5X4LF8Hfi6Ct+zdeNgf9SH
EvAcvQsi4nnUd2Ucvwt4D7QGR8C5gv9Z+dl7qYP9CPsJ9h7n03+A/bLd08vF
9pOg8Xi/4ZB1eUfIurwTRP+5yqfKezMC9xXfKa9b3pP6F57CZ583887Dny/8
Wby85xfEk3WygOcCXgH7A/YH3f963fO9HMBjgR4OeHng4nuScRqL72r1qTh3
/x13xT6+IzvEoS/qyu4bwWuqrLNPkTfXR8SpFjeP/b6yn7h66APmmS/M89rv
rFwHNl/YT3ro+feCtb+rPb+brIsfWd/Xc55aXgtw815k3jPPF+AK8Bfgj304
15Hdx3uddZ5/B9t11j3fZ4wj4z4Ucduvm1qd5fvC6uyrrO+yz9rz2HfL77Yf
9xF+y76x3w9Y5/ydzLqv9WnWEf/3qNUp+bIvHfUp1jPrvKz7Wh7I+n7e8H+f
su7265Z9Idc9z7X2GedfmzmPoA==
        "]], {}}, {}}, 
    {PointSize[0.025], 
     {RGBColor[1, 0, 0], Point3DBox[{1, 0, 0}]}, 
     Line3DBox[{{0, 0, 0}, {1, 0, 0}}]}},
   Axes->True,
   BaseStyle->{FontFamily -> "Arial"},
   DisplayFunction->Identity,
   FaceGridsStyle->Automatic,
   ImagePadding->Automatic,
   Method->{
    "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}},
   PlotRange->{{-1, 1}, {-1, 1}, {-1, 1}},
   PlotRangePadding->{{0, 0}, {0, 0}, {0, 0}},
   Ticks->{Automatic, Automatic, Automatic}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.860261074027746*^9, 3.8602610906158113`*^9}, {
   3.860261132149598*^9, 3.860261152738028*^9}, 3.860261340458745*^9, {
   3.860261508840746*^9, 3.8602615433925056`*^9}, {3.860261982977034*^9, 
   3.8602620097033787`*^9}, 3.860262201077154*^9, 3.860262284161655*^9, 
   3.8603202397050657`*^9, 3.860320601878263*^9, 3.8603207353008966`*^9, 
   3.860321158964457*^9, 3.86032176824254*^9, 3.860321813279183*^9},
 CellLabel->"Out[18]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ExpressionUUID->"b2621b3d-93f0-42a4-80a5-392408c50b51"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "An", " ", "animation", " ", "of", " ", "the", " ", "spherical", " ", 
    RowBox[{"pendulum", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"PendulumAnimated", "=", 
    RowBox[{"Animate", "[", 
     RowBox[{
      RowBox[{"Pendulum", "[", "t", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", 
        RowBox[{"2", "\[Pi]", "*", "3"}], ",", "0.25"}], "}"}], ",", 
      RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "The", " ", "same", " ", "for", " ", "the", " ", "pendulum", " ", "with", 
     " ", 
     RowBox[{"track", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"PendulumTrackAnimated", "=", 
    RowBox[{"Animate", "[", 
     RowBox[{
      RowBox[{"PendulumTrack", "[", "t", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", 
        RowBox[{"2", "\[Pi]", "*", "3"}], ",", "0.25"}], "}"}], ",", 
      RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]}]}]}]], "Input",\

 CellChangeTimes->{{3.860261587194764*^9, 3.860261588243127*^9}, {
  3.860261914824963*^9, 3.860261923576511*^9}, {3.860262291845868*^9, 
  3.8602623197262917`*^9}, {3.860262494924367*^9, 3.860262513278661*^9}, {
  3.860320249968862*^9, 3.860320251550013*^9}, {3.860320638670417*^9, 
  3.860320646742671*^9}, {3.8603208093087053`*^9, 3.8603208541458673`*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"cfdf2ccd-5480-4654-a5e1-dd899115f1ee"],

Cell[BoxData[
 FormBox[
  TagBox[
   FormBox[
    StyleBox[
     DynamicModuleBox[{$CellContext`t$$ = 0, Typeset`show$$ = True, 
      Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
      Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
      "\"untitled\"", Typeset`specs$$ = {{
        Hold[$CellContext`t$$], 0, 6 Pi, 0.25}}, Typeset`size$$ = {
      360., {193., 198.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
      Typeset`skipInitDone$$ = False, $CellContext`t$1278$$ = 0}, 
      DynamicBox[Manipulate`ManipulateBoxes[
       1, TraditionalForm, "Variables" :> {$CellContext`t$$ = 0}, 
        "ControllerVariables" :> {
          Hold[$CellContext`t$$, $CellContext`t$1278$$, 0]}, 
        "OtherVariables" :> {
         Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
          Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
          Typeset`specs$$, Typeset`size$$, Typeset`update$$, 
          Typeset`initDone$$, Typeset`skipInitDone$$}, 
        "Body" :> $CellContext`Pendulum[$CellContext`t$$], 
        "Specifications" :> {{$CellContext`t$$, 0, 6 Pi, 0.25, 
           AppearanceElements -> {
            "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
             "DirectionButton"}}}, 
        "Options" :> {
         ControlType -> Animator, AppearanceElements -> None, 
          DefaultBaseStyle -> "Animate", DefaultLabelStyle -> "AnimateLabel", 
          SynchronousUpdating -> True, ShrinkingDelay -> 10.}, 
        "DefaultOptions" :> {}],
       ImageSizeCache->{405., {230., 236.}},
       SingleEvaluation->True],
      Deinitialization:>None,
      DynamicModuleValues:>{},
      Initialization:>({$CellContext`Pendulum[
           Pattern[$CellContext`t, 
            Blank[]]] := Graphics3D[{{
             PointSize[0.025], 
             $CellContext`ball[$CellContext`t], 
             $CellContext`thread[$CellContext`t]}}, 
           PlotRange -> {{-1, 1}, {-1, 1}, {-1, 1}}, Axes -> True, Ticks -> 
           False], $CellContext`ball[
           Pattern[$CellContext`t, 
            Blank[]]] := {Red, 
           Point[{
             $CellContext`x[$CellContext`t], 
             $CellContext`y[$CellContext`t], 
             $CellContext`z[$CellContext`t]}]}, $CellContext`x[
           Pattern[$CellContext`t, 
            Blank[]]] := $CellContext`r Sin[
            $CellContext`\[Theta][$CellContext`t]] Cos[
            $CellContext`\[Phi][$CellContext`t]], $CellContext`r = 
         1, $CellContext`\[Theta][
           Pattern[$CellContext`t, 
            Blank[]]] := 
         Pi - $CellContext`\[Theta]P[$CellContext`t], $CellContext`\[Theta]P[
           Pattern[$CellContext`t, 
            Blank[]]] := $CellContext`\[Theta]P0 
          Cos[$CellContext`\[Omega] $CellContext`t], $CellContext`\[Theta]P0 = 
         Pi - $CellContext`\[Theta]0, $CellContext`\[Theta]0 = 
         Pi/2, $CellContext`\[Omega] = 1, $CellContext`\[Phi][
           Pattern[$CellContext`t, 
            Blank[]]] := 0, $CellContext`y[
           Pattern[$CellContext`t, 
            Blank[]]] := $CellContext`r Sin[
            $CellContext`\[Theta][$CellContext`t]] Sin[
            $CellContext`\[Phi][$CellContext`t]], $CellContext`z[
           Pattern[$CellContext`t, 
            Blank[]]] := $CellContext`r Cos[
            $CellContext`\[Theta][$CellContext`t]], $CellContext`thread[
           Pattern[$CellContext`t, 
            Blank[]]] := Line[{{0, 0, 0}, {
             $CellContext`x[$CellContext`t], 
             $CellContext`y[$CellContext`t], 
             $CellContext`z[$CellContext`t]}}]}; Typeset`initDone$$ = True),
      SynchronousInitialization->True,
      UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
      UnsavedVariables:>{Typeset`initDone$$},
      UntrackedVariables:>{Typeset`size$$}], "Animate",
     Deployed->True,
     StripOnInput->False],
    TraditionalForm],
   Manipulate`InterpretManipulate[1]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.860320252336816*^9, 3.8603206178307133`*^9, 3.860320735413918*^9, {
   3.8603208138035603`*^9, 3.860320854573401*^9}, 3.860321159295883*^9, 
   3.860321768397215*^9, 3.860321813402389*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"9e44e956-07eb-4224-a439-4556dbe59e55"],

Cell[BoxData[
 FormBox[
  TagBox[
   FormBox[
    StyleBox[
     DynamicModuleBox[{$CellContext`t$$ = 0, Typeset`show$$ = True, 
      Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
      Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
      "\"untitled\"", Typeset`specs$$ = {{
        Hold[$CellContext`t$$], 0, 6 Pi, 0.25}}, Typeset`size$$ = {
      360., {193., 198.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
      Typeset`skipInitDone$$ = False, $CellContext`t$1314$$ = 0}, 
      DynamicBox[Manipulate`ManipulateBoxes[
       1, TraditionalForm, "Variables" :> {$CellContext`t$$ = 0}, 
        "ControllerVariables" :> {
          Hold[$CellContext`t$$, $CellContext`t$1314$$, 0]}, 
        "OtherVariables" :> {
         Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
          Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
          Typeset`specs$$, Typeset`size$$, Typeset`update$$, 
          Typeset`initDone$$, Typeset`skipInitDone$$}, 
        "Body" :> $CellContext`PendulumTrack[$CellContext`t$$], 
        "Specifications" :> {{$CellContext`t$$, 0, 6 Pi, 0.25, 
           AppearanceElements -> {
            "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
             "DirectionButton"}}}, 
        "Options" :> {
         ControlType -> Animator, AppearanceElements -> None, 
          DefaultBaseStyle -> "Animate", DefaultLabelStyle -> "AnimateLabel", 
          SynchronousUpdating -> True, ShrinkingDelay -> 10.}, 
        "DefaultOptions" :> {}],
       ImageSizeCache->{405., {230., 236.}},
       SingleEvaluation->True],
      Deinitialization:>None,
      DynamicModuleValues:>{},
      Initialization:>({$CellContext`PendulumTrack[
           Pattern[$CellContext`t, 
            Blank[]]] := Graphics3D[{{
             PointSize[0.025], 
             $CellContext`ball[$CellContext`t], 
             $CellContext`thread[$CellContext`t]}, 
            $CellContext`track[$CellContext`t]}, 
           PlotRange -> {{-1, 1}, {-1, 1}, {-1, 1}}, Axes -> True, Ticks -> 
           False], $CellContext`ball[
           Pattern[$CellContext`t, 
            Blank[]]] := {Red, 
           Point[{
             $CellContext`x[$CellContext`t], 
             $CellContext`y[$CellContext`t], 
             $CellContext`z[$CellContext`t]}]}, $CellContext`x[
           Pattern[$CellContext`t, 
            Blank[]]] := $CellContext`r Sin[
            $CellContext`\[Theta][$CellContext`t]] Cos[
            $CellContext`\[Phi][$CellContext`t]], $CellContext`r = 
         1, $CellContext`\[Theta][
           Pattern[$CellContext`t, 
            Blank[]]] := 
         Pi - $CellContext`\[Theta]P[$CellContext`t], $CellContext`\[Theta]P[
           Pattern[$CellContext`t, 
            Blank[]]] := $CellContext`\[Theta]P0 
          Cos[$CellContext`\[Omega] $CellContext`t], $CellContext`\[Theta]P0 = 
         Pi - $CellContext`\[Theta]0, $CellContext`\[Theta]0 = 
         Pi/2, $CellContext`\[Omega] = 1, $CellContext`\[Phi][
           Pattern[$CellContext`t, 
            Blank[]]] := 0, $CellContext`y[
           Pattern[$CellContext`t, 
            Blank[]]] := $CellContext`r Sin[
            $CellContext`\[Theta][$CellContext`t]] Sin[
            $CellContext`\[Phi][$CellContext`t]], $CellContext`z[
           Pattern[$CellContext`t, 
            Blank[]]] := $CellContext`r Cos[
            $CellContext`\[Theta][$CellContext`t]], $CellContext`thread[
           Pattern[$CellContext`t, 
            Blank[]]] := Line[{{0, 0, 0}, {
             $CellContext`x[$CellContext`t], 
             $CellContext`y[$CellContext`t], 
             $CellContext`z[$CellContext`t]}}], $CellContext`track[
           Pattern[$CellContext`t, 
            Blank[]]] := {Green, 
           Line[
            Map[Evaluate[{
               $CellContext`x[#], 
               $CellContext`y[#], 
               $CellContext`z[#]}]& , 
             Range[0, $CellContext`t, 0.025]]]}}; Typeset`initDone$$ = True),
      SynchronousInitialization->True,
      UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
      UnsavedVariables:>{Typeset`initDone$$},
      UntrackedVariables:>{Typeset`size$$}], "Animate",
     Deployed->True,
     StripOnInput->False],
    TraditionalForm],
   Manipulate`InterpretManipulate[1]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.860320252336816*^9, 3.8603206178307133`*^9, 3.860320735413918*^9, {
   3.8603208138035603`*^9, 3.860320854573401*^9}, 3.860321159295883*^9, 
   3.860321768397215*^9, 3.860321813451872*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"1079b784-2f10-4fd5-8200-5268d0fd873b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "Combine", " ", "the", " ", "animation", " ", "of", " ", "the", " ", 
      "pendulum", " ", "with", " ", "the", " ", "2"}], "-", "sphere"}], ",", 
    " ", 
    RowBox[{
    "where", " ", "we", " ", "only", " ", "use", " ", "the", " ", "variant", 
     " ", "with", " ", 
     RowBox[{"track", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Animate", "[", 
   RowBox[{
    RowBox[{"Show", "[", 
     RowBox[{"Sphere2", ",", 
      RowBox[{"PendulumTrack", "[", "t", "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      RowBox[{"2", "\[Pi]", "*", "3"}], ",", "0.25"}], "}"}], ",", 
    RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.860262609227022*^9, 3.860262686471733*^9}, {
  3.8603202930704403`*^9, 3.860320296370523*^9}, {3.86032065611117*^9, 
  3.8603206942552767`*^9}, {3.860320878644774*^9, 3.860320922979764*^9}, {
  3.860321055103869*^9, 3.860321088635758*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"211e599f-a938-4678-aa9a-3aa21e111218"],

Cell[BoxData[
 FormBox[
  TagBox[
   FormBox[
    StyleBox[
     DynamicModuleBox[{$CellContext`t$$ = 9., Typeset`show$$ = True, 
      Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
      Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
      "\"untitled\"", Typeset`specs$$ = {{
        Hold[$CellContext`t$$], 0, 6 Pi, 0.25}}, Typeset`size$$ = {
      360., {200., 205.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
      Typeset`skipInitDone$$ = False, $CellContext`t$1345$$ = 0}, 
      DynamicBox[Manipulate`ManipulateBoxes[
       1, TraditionalForm, "Variables" :> {$CellContext`t$$ = 0}, 
        "ControllerVariables" :> {
          Hold[$CellContext`t$$, $CellContext`t$1345$$, 0]}, 
        "OtherVariables" :> {
         Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
          Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
          Typeset`specs$$, Typeset`size$$, Typeset`update$$, 
          Typeset`initDone$$, Typeset`skipInitDone$$}, "Body" :> 
        Show[$CellContext`Sphere2, 
          $CellContext`PendulumTrack[$CellContext`t$$]], 
        "Specifications" :> {{$CellContext`t$$, 0, 6 Pi, 0.25, 
           AppearanceElements -> {
            "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
             "DirectionButton"}}}, 
        "Options" :> {
         ControlType -> Animator, AppearanceElements -> None, 
          DefaultBaseStyle -> "Animate", DefaultLabelStyle -> "AnimateLabel", 
          SynchronousUpdating -> True, ShrinkingDelay -> 10.}, 
        "DefaultOptions" :> {}],
       ImageSizeCache->{405., {237., 243.}},
       SingleEvaluation->True],
      Deinitialization:>None,
      DynamicModuleValues:>{},
      Initialization:>({$CellContext`Sphere2 = Graphics3D[{{
             GraphicsComplex[CompressedData["
1:eJyFWHtYjdkertyZM9E4uV8PBrl7jks1++NIuRzEMELul3REYsZxq3RcxsiE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              "], {{{
                 EdgeForm[], Lighting -> Automatic, 
                 GrayLevel[1], 
                 Opacity[0.1], 
                 Specularity[
                  GrayLevel[1], 10], 
                 GraphicsGroup[
                  Annotation[{
                    Polygon[CompressedData["
1:eJwtlEtIlVEUhfc2NTUtyIEWqWla10grCjWvj1tqWWaaPRWECIRGCk1slNA0
R0KjhCY5FAqCsvc7g5rUIKlBD6JEJIsaFCW0FnsNPva95z9nP9c5pSeHegbT
zGwYLAF3QbmbtcKeAutABsjHWi5sN/gOcsAOMCnL/4WgBmCrHQWXQR7YAg6D
LDAKkiAbNIMhsAysBRdAumJug5My2HugFr/3wB6hLw/f73RuPfjHnEEF6Aft
yvk2+AxawAfwAHSCIsVjrDGd5f5D6gNzXoU4j2F7wFtwXf5Z0wbtIdPgGOgD
xRY9Klce9HlVPeN6CXvgETsD9hbsTtYH6vG/DnYl7CPYLtXHOln7J9AImiz2
Tarnu8Fr0AYm9J3re5knfO2Dfa6cE/o+oD3vwX2wn/2WD86lRbUfBA2aH2e3
GfSCperxOdXYofpztV7hEX857EPYA+rRuHrGmc4od+Z3UWdfghugUvNJefSM
cc4qFrUzqDzp97TyoY52qWdrPHJiXedVQ5ZirVBu1EaJx5lFzZda+mGh53r1
iFovVY4dypNaviafxZox1xvg76ZmWuXR60bN66/mfMZi7rxzd0CZhz7ps9pD
4+nykwILqpn5FHnMq1M5/bS4I+S3xb1pw54nFrodsdB8JvgmH6zto3rC3FZr
P7XP2HPKZdZCh9Qu79u8vr+xuAfUOGfT5NGDYe3jfPkGXLJ4BzZ5xGG8rxZ6
oLYLPGadUN5jmu+4cslTbzOlAWpzu4dm2Ot8abvQQxuV2jMqbTwDryz0Oi1/
vAOcfbaHTp+CF+C4hdZPWLyBzL/OY17s7VaPfpMJ6YL+N3qc/aXeJjXjP/KR
hu9TFu/cgHSQo7l/sXhj+d5e0YyS2p9SbgmPe/MfEOh7cA==
                    "]], 
                    Polygon[CompressedData["
1:eJxNlnmw0FMUx8+vkqW072l9bVpULy2vlZQlxthirI3KsyUMMdZBlK3N0oKi
opRkhPxhxjKGiSIR0RQpW3mWVK+y5fuZ823GH5+553fPvfd37rnnnnPbjL72
rPFVIuJtUU00KiIaiHLJl0fKC9TWi+y7X9RS3+lqDxXfi+/EdeJ6+qSrLi6U
fJF4R2wRXUV1sdxzGNtQnCqO8vgLRCvJM9XWEEP5r76PFDVFXXGn+pqovULt
IaK35GMBWZRJ7ieaSm4mXnAfcgPRS3JJ5Hz297zXYG598bOoEDeJCWKeOFr6
bmrriDaSZ6udJVpL7i6OET31XSraSz5Z7cXiEtFJ33PVPiXOEx3Fs2Ih+5eu
i3hAcl0xJtLXrFlqn38lPhfrxZfieOluU9vY9h2n79ZqW+BHMazIMRO8hw/F
Kv/3A7FGvG9bVnsP7GWmfb/aulWey/k8KZ4Qm8VG8YVtwrYORe6ZvY5i/2KD
x2y0zdj+mTjRa7DWHLFJzBd/eu/4YLZ93FltbeJG8oORPuri2GrpWCFm6ui7
hjhC1HaM1HRfHfehO1ycovFn20f45max0mc+wT59g7iS/mq1VWzjHNuCTVWk
W6p2iSgkf+0x6Lp4LD4Z5TkDxbeR8dHDc5Y47sJrseaQyJj/VSyLjNtfmCfd
IrXP4Rev91CkT7o69odL7hV5B0r1vThyTk/fhT6Sm0TeCWKZmJ7r2FzsOeWO
N2JyoeOQu1+m9kXbhG3E+jneS0+f3V9irM+wwv7cIUZax5j9oq94NDJHkBtq
iVfEEH03V9vIe2bv3NVxjpsp4uHIfa51XBLLHzsOp4mpjrNt9vcgsdUyfaW2
d5H7B9unJ+jfd6i9XQy1TN+ZaqtG5rtPxTox2WMYyx3knk1S+4ntus/yatu4
1vPWuA/dYtuz1bZsc18927glMqaIJXJm1SLj5Eo1V0WeTQ/nnQU+O3Iauazc
upE+p+7WMYZYaBsZ26zJWsR4tSJjMty/3r6cYt9/E3lnN9muze47LTI3cM+n
+ww4C+7+DPehaycecd8G+3CdfTHJPlvrs7zXvsbn1Jbz3YfuIzFRrBA/iTPE
y2K7Y4jYuVHsETtFf7FbvCR+iKw5yz12u9dgrR/9zdwbIuP2NfFqZJwTyyvd
t8Prcg+I09/EALfXiPGW0Y1z367Ie/u7+MMgl9nOSvfttO3EZbci79NlYl/k
ubHOXvFvZI59XfxjP+/1OtNMpdeaat0u/6PS57DP/dN9NiXum+E5e+y7KWa3
98kd5B4/I56OzCsHxN+2CdtmucU2aspsjzmoO+A+ciM5ktww32vu91oHrKOm
UCs6FplTya3UznMj45y7QD7rTA2OrNGPicOKzDHkmscj6yN96MhvjUWnyJp4
t2ip7xbirkhdQ7+BeAtRi0qKvI/k+Hcj3yTUGWKQukJc3hNZ93kbEb/EOe8W
/tsqsm5hU/3/1aURkbV1hPfIXlmzrsfU97+xgTrdtkhbsZncSQ5F367IXIGN
7exDfMcbhPzbz7E01mfC2XSIrDfce2oRbx9yTIX9S22kRg4u8p5w16i7zV0/
eAuNjqwjzYqsq7xxyOXcsRWeO89zGMPYJvYr+Yo3WNMi9ax1aeRbsKXrA/Wd
Ok6OIA9Qx/EpviV31HRtRzfRZ4Ev3ox8a3b1mIN5hrWGF5nDyd28AwaJWyPf
orxJeU+xh8E+N+pzX2qo6zY6xvDWam7dW5Fvmz4eh0xd5l1JHaJO83bpZpDH
+DyWeF5vn0P/IuskdbvMtmHjQHFLZC3u53HLHDe8a9r7jiyzjrnU0QHeI3vj
jf5epA+G+cywf6lj4STxHwevVMc=
                    "]], 
                    Polygon[CompressedData["
1:eJwt0blOgkEQwPFdjlIKCkVR8ApBC3wAISpobDwiFXbqAwiBRhsl8EDQqZze
xkRNoPJI1EJQ34L/5Jvil5kh3+7MDlMH2fShyxgThBdVtLCKPiqYtsZMIowG
dQpdPCCDJ3Twj19s4wZ/uMUo5/aJe9jRe5t6zw96eMEjojjHM+Y5N4co7rVX
gnwRy+Q1xMmviT7iEPzW6S9nZb5dLCBmnO9kvgLy2NL+8qYkssjhAi7OW3i0
V9A670iT32GMfBYz1tlPU3d2iS984hubuoMU3ySxpnfI7HK3G16sUB/reySv
40hnkffmdL4lhKjHsaH9JsiLGqXfFU51jyP8NoyA7JL6DO94wwciGqV+RRvr
KOt/IGdOUMIACWs/aQ==
                    "]]}, 
                   "Charting`Private`Tag$1208#1"]]}, {}, {}, {}, {}}, {{
                 Directive[
                  GrayLevel[0.3], 
                  Opacity[0.1]], 
                 
                 Line[{24, 1, 159, 160, 161, 17, 137, 138, 139, 8, 180, 181, 
                  182, 23, 123, 124, 125, 3, 96, 97, 98, 16, 45, 46, 47, 7, 
                  114, 115, 116, 22, 27, 28, 29, 4, 149, 148, 147, 14, 129, 
                  128, 127, 6, 176, 175, 174, 21, 122, 121, 120, 2, 107, 106, 
                  105, 19, 53, 52, 51, 9, 110, 109, 108, 20, 26, 25, 
                  24}]}, {}, {}, {
                 Opacity[0.1], 
                 
                 Line[{24, 54, 249, 250, 99, 299, 300, 60, 48, 84, 234, 235, 
                  117, 321, 322, 323, 81, 96}], 
                 
                 Line[{29, 32, 264, 263, 92, 286, 285, 77, 224, 44, 292, 68, 
                  230, 229, 113, 317, 316, 65, 261, 107}], 
                 
                 Line[{7, 136, 135, 134, 133, 132, 131, 130, 5, 146, 145, 144,
                   143, 142, 141, 140, 9}], 
                 
                 Line[{47, 89, 210, 209, 208, 207, 206, 205, 41, 280, 104, 35,
                   248, 247, 246, 245, 244, 59, 110}], 
                 
                 Line[{51, 69, 211, 212, 213, 214, 215, 36, 93, 72, 265, 266, 
                  267, 268, 269, 270, 78, 114}], 
                 
                 Line[{16, 158, 157, 156, 13, 164, 163, 162, 18, 167, 166, 
                  165, 10, 173, 172, 171, 20}], 
                 
                 Line[{98, 283, 282, 83, 119, 86, 304, 303, 50, 227, 226, 62, 
                  101, 56, 314, 313, 26}], 
                 
                 Line[{19, 168, 169, 170, 11, 150, 151, 152, 15, 153, 154, 
                  155, 12, 177, 178, 179, 22}], 
                 
                 Line[{105, 256, 257, 258, 63, 111, 66, 287, 288, 289, 42, 
                  220, 221, 75, 90, 30, 318, 319, 27}], 
                 
                 Line[{108, 237, 238, 57, 240, 33, 305, 306, 102, 276, 277, 
                  39, 200, 87, 296, 297, 45}], 
                 
                 Line[{116, 233, 232, 80, 275, 74, 295, 294, 95, 255, 254, 
                  253, 38, 219, 71, 311, 310, 309, 53}], 
                 
                 Line[{25, 312, 55, 251, 100, 301, 61, 225, 49, 302, 85, 236, 
                  118, 324, 325, 82, 281, 97}], 
                 
                 Line[{28, 320, 31, 262, 91, 284, 76, 223, 222, 43, 291, 290, 
                  67, 228, 112, 315, 64, 260, 259, 106}], 
                 Line[{46, 298, 88, 204, 203, 202, 201, 40, 279, 278, 103, 
                  307, 34, 243, 242, 241, 58, 239, 109}], 
                 
                 Line[{52, 308, 70, 216, 217, 218, 37, 252, 94, 293, 73, 271, 
                  272, 273, 274, 79, 231, 115}]}, {
                 Opacity[0.1], 
                 
                 Line[{120, 187, 261, 259, 256, 168, 309, 308, 69, 140, 59, 
                  239, 237, 171, 313, 312, 54, 159}], 
                 
                 Line[{125, 323, 196, 281, 283, 158, 297, 298, 199, 210, 136, 
                  270, 194, 231, 233, 179, 319, 320, 32, 149}], 
                 
                 Line[{6, 44, 43, 42, 15, 95, 94, 93, 5, 104, 103, 102, 18, 
                  50, 49, 48, 8}], 
                 
                 Line[{127, 193, 224, 222, 220, 153, 294, 293, 72, 130, 126, 
                  280, 278, 276, 162, 303, 302, 84, 180}], 
                 
                 Line[{139, 60, 225, 227, 167, 306, 307, 35, 146, 36, 252, 
                  255, 152, 289, 291, 292, 190, 176}], 
                 
                 Line[{14, 92, 91, 90, 12, 275, 272, 267, 133, 207, 202, 200, 
                  13, 119, 118, 117, 23}], 
                 
                 Line[{147, 263, 262, 30, 177, 80, 273, 268, 134, 208, 203, 
                  87, 156, 83, 324, 321, 123}], 
                 
                 Line[{17, 99, 100, 101, 10, 240, 242, 246, 143, 213, 217, 
                  219, 11, 111, 112, 113, 21}], 
                 
                 Line[{161, 250, 251, 56, 173, 57, 241, 245, 142, 212, 216, 
                  191, 311, 170, 258, 185, 315, 317, 122}], 
                 
                 Line[{174, 229, 228, 188, 287, 150, 253, 183, 218, 214, 144, 
                  247, 243, 33, 165, 62, 301, 299, 137}], 
                 
                 Line[{182, 235, 236, 86, 164, 39, 201, 206, 132, 266, 271, 
                  74, 155, 75, 284, 286, 129}], 
                 
                 Line[{121, 316, 186, 260, 257, 169, 310, 70, 211, 141, 244, 
                  58, 238, 172, 314, 55, 249, 160}], 
                 
                 Line[{124, 322, 325, 197, 282, 157, 296, 198, 204, 209, 135, 
                  269, 274, 195, 232, 178, 318, 31, 264, 148}], 
                 
                 Line[{128, 285, 192, 223, 221, 154, 295, 73, 265, 131, 205, 
                  184, 279, 277, 163, 304, 85, 234, 181}], 
                 
                 Line[{138, 300, 61, 226, 166, 305, 34, 248, 145, 215, 37, 
                  254, 151, 288, 290, 189, 230, 175}]}}}, 
              VertexNormals -> CompressedData["
1:eJx1WXk4ldv3J5WiJJVIUhGFUkqho0WSVCqlUUkSGkQyNBkqQ0WFTCGphEQk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               "], 
              VertexTextureCoordinates -> CompressedData["
1:eJyVmEGO1TAMhttBrNlwAU7yVlyAIyCx5mo9QpddRppKVJosqip6ytMbUPYg
QHRqR/7STEs2lhPH+X/XdvLeh89fP315aJrmY9s0/+T+SJfX5ylnyKN5GVyX
4S5Wxopem08Vuxn2xMNzZ+ynnYx0gEOGzHeY76EPqv9Zx039veh31X+v+nes
3yDvKsXe7hshJ0gPuUAPat+u8rqd96h+Zd7aBfXTbn4t3xl8Z+CegTsBdwLO
hPjL/h76AF34ygiqW14yOpzTQw6QI/QJ9h7+Osz32Jf9SjzfbPMSz7fbPonn
u82vzZtH5M03tf+1yifER3AFxSXxkfOt/QL7oPY2j27Q75o/gucBfl/Wf8D/
c+FXcFv7Xu0lnrS3+HucMyDfR+yf4N/r+dYuIv8j8j8CxwwcM3DMwJ+APyl+
q4u9g72DvVO+9rwJulfd8pV+d1fd8pUxQp+ge/i7KT7r3yGeDvFMiGdCPBmf
iPhExIf3wtnvQB71OLWGP3mc5cW+dzav8j37f31cxtnvyjw+28d5r5/N0wQ+
R/dwhP8I/xH+WceiB9VtvB3wHOW1jLPvDtaBAx5X4LF8Hfi6Ct+zdeNgf9SH
EvAcvQsi4nnUd2Ucvwt4D7QGR8C5gv9Z+dl7qYP9CPsJ9h7n03+A/bLd08vF
9pOg8Xi/4ZB1eUfIurwTRP+5yqfKezMC9xXfKa9b3pP6F57CZ583887Dny/8
Wby85xfEk3WygOcCXgH7A/YH3f963fO9HMBjgR4OeHng4nuScRqL72r1qTh3
/x13xT6+IzvEoS/qyu4bwWuqrLNPkTfXR8SpFjeP/b6yn7h66APmmS/M89rv
rFwHNl/YT3ro+feCtb+rPb+brIsfWd/Xc55aXgtw815k3jPPF+AK8Bfgj304
15Hdx3uddZ5/B9t11j3fZ4wj4z4Ucduvm1qd5fvC6uyrrO+yz9rz2HfL77Yf
9xF+y76x3w9Y5/ydzLqv9WnWEf/3qNUp+bIvHfUp1jPrvKz7Wh7I+n7e8H+f
su7265Z9Idc9z7X2GedfmzmPoA==
               "]], {}}, {}}, {
           DisplayFunction -> Identity, ImagePadding -> Automatic, 
            PlotRangePadding -> {{0, 0}, {0, 0}, {0, 0}}, DisplayFunction -> 
            Identity, DisplayFunction -> Identity, 
            PlotRange -> {{-1, 1}, {-1, 1}, {-1, 1}}, 
            PlotRangePadding -> {{0, 0}, {0, 0}, {0, 0}}, ImagePadding -> All,
             DisplayFunction -> Identity, Axes -> True, 
            BaseStyle -> {FontFamily -> "Arial"}, DisplayFunction :> Identity,
             FaceGridsStyle -> Automatic, 
            Method -> {
             "DefaultGraphicsInteraction" -> {
               "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                "Effects" -> {
                 "Highlight" -> {"ratio" -> 2}, 
                  "HighlightPoint" -> {"ratio" -> 2}, 
                  "Droplines" -> {
                   "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}}, 
            PlotRange -> {{-1, 1}, {-1, 1}, {-1, 1}}, 
            PlotRangePadding -> {Automatic, Automatic, Automatic}, 
            Ticks -> {
             Automatic, Automatic, Automatic}}], $CellContext`PendulumTrack[
           Pattern[$CellContext`t, 
            Blank[]]] := Graphics3D[{{
             PointSize[0.025], 
             $CellContext`ball[$CellContext`t], 
             $CellContext`thread[$CellContext`t]}, 
            $CellContext`track[$CellContext`t]}, 
           PlotRange -> {{-1, 1}, {-1, 1}, {-1, 1}}, Axes -> True, Ticks -> 
           False], $CellContext`ball[
           Pattern[$CellContext`t, 
            Blank[]]] := {Red, 
           Point[{
             $CellContext`x[$CellContext`t], 
             $CellContext`y[$CellContext`t], 
             $CellContext`z[$CellContext`t]}]}, $CellContext`x[
           Pattern[$CellContext`t, 
            Blank[]]] := $CellContext`r Sin[
            $CellContext`\[Theta][$CellContext`t]] Cos[
            $CellContext`\[Phi][$CellContext`t]], $CellContext`r = 
         1, $CellContext`\[Theta][
           Pattern[$CellContext`t, 
            Blank[]]] := 
         Pi - $CellContext`\[Theta]P[$CellContext`t], $CellContext`\[Theta]P[
           Pattern[$CellContext`t, 
            Blank[]]] := $CellContext`\[Theta]P0 
          Cos[$CellContext`\[Omega] $CellContext`t], $CellContext`\[Theta]P0 = 
         Pi/2, $CellContext`\[Omega] = 1, $CellContext`\[Phi][
           Pattern[$CellContext`t, 
            Blank[]]] := 0, $CellContext`y[
           Pattern[$CellContext`t, 
            Blank[]]] := $CellContext`r Sin[
            $CellContext`\[Theta][$CellContext`t]] Sin[
            $CellContext`\[Phi][$CellContext`t]], $CellContext`z[
           Pattern[$CellContext`t, 
            Blank[]]] := $CellContext`r Cos[
            $CellContext`\[Theta][$CellContext`t]], $CellContext`thread[
           Pattern[$CellContext`t, 
            Blank[]]] := Line[{{0, 0, 0}, {
             $CellContext`x[$CellContext`t], 
             $CellContext`y[$CellContext`t], 
             $CellContext`z[$CellContext`t]}}], $CellContext`track[
           Pattern[$CellContext`t, 
            Blank[]]] := {Green, 
           Line[
            Map[Evaluate[{
               $CellContext`x[#], 
               $CellContext`y[#], 
               $CellContext`z[#]}]& , 
             Range[0, $CellContext`t, 0.025]]]}}; Typeset`initDone$$ = True),
      SynchronousInitialization->True,
      UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
      UnsavedVariables:>{Typeset`initDone$$},
      UntrackedVariables:>{Typeset`size$$}], "Animate",
     Deployed->True,
     StripOnInput->False],
    TraditionalForm],
   Manipulate`InterpretManipulate[1]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.860262633855837*^9, 3.860262686957662*^9}, 
   3.860320319173938*^9, 3.860320408005683*^9, 3.860320498329406*^9, 
   3.860320696183786*^9, 3.860320735595696*^9, {3.8603208742316113`*^9, 
   3.860320886721943*^9}, 3.860320924082815*^9, {3.860321061053876*^9, 
   3.8603210736946993`*^9}, 3.8603211594645987`*^9, 3.860321768575759*^9, 
   3.8603218136731777`*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"c7319d43-21bd-4da8-96f9-3790452e4ee2"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1016, 654},
WindowMargins->{{Automatic, 101}, {Automatic, 9}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 229, 4, 97, "Title",ExpressionUUID->"3fdecc31-cf61-4b71-9602-fb732812456f"],
Cell[812, 28, 176, 3, 40, "Author",ExpressionUUID->"c17b5c93-8911-4db4-b8c9-aa1ea5265938"],
Cell[991, 33, 152, 3, 42, "Date",ExpressionUUID->"efd0bedd-383f-4c42-8bd3-95f7358f5558"],
Cell[1146, 38, 2987, 82, 236, "Text",ExpressionUUID->"612daef6-112f-4f9f-a173-f42955c48a1a"],
Cell[CellGroupData[{
Cell[4158, 124, 156, 3, 69, "Section",ExpressionUUID->"c3bd4301-8b5f-417a-95d4-b0b9d4dea1fd"],
Cell[4317, 129, 1325, 35, 126, "Input",ExpressionUUID->"274d2242-5ff7-4b69-8807-54da9078f407"],
Cell[5645, 166, 695, 18, 63, "Input",ExpressionUUID->"b02aef6a-50b2-4e7a-be2c-2ff14b57e680"],
Cell[6343, 186, 811, 22, 84, "Input",ExpressionUUID->"cca295d8-9c14-41fc-b9a2-799da4acc9ea"],
Cell[7157, 210, 1093, 25, 147, "Input",ExpressionUUID->"3639b5fc-705a-489f-a6dd-c7133b3c17fc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8287, 240, 149, 3, 69, "Section",ExpressionUUID->"a44e2a30-f0b8-4dba-bd92-9caa2e09d3ef"],
Cell[CellGroupData[{
Cell[8461, 247, 2107, 50, 105, "Input",ExpressionUUID->"0503829a-4721-40c5-ba90-5e7ede3edfcb"],
Cell[10571, 299, 161083, 2656, 429, 21300, 365, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"bef4810d-2f80-4765-ac33-25220af98794"]
}, Open  ]],
Cell[171669, 2958, 1876, 44, 147, "Input",ExpressionUUID->"8b83da87-b3a8-4605-a859-d3a4ab22294d"],
Cell[173548, 3004, 727, 19, 63, "Input",ExpressionUUID->"e32e07db-bcfa-428f-84b8-ad2e7e193752"],
Cell[174278, 3025, 795, 21, 63, "Input",ExpressionUUID->"0496fa40-cc3c-4b14-af91-a68a47c6cf41"],
Cell[175076, 3048, 1074, 27, 63, "Input",ExpressionUUID->"0cf089cf-6620-4f9a-99d1-5491cac6ced5"],
Cell[176153, 3077, 2888, 72, 168, "Input",ExpressionUUID->"492b59cb-38fb-4f75-ab57-76c3e1a5dfb3"],
Cell[CellGroupData[{
Cell[179066, 3153, 652, 12, 63, "Input",ExpressionUUID->"981ffc55-b631-490a-8609-a87476cce184"],
Cell[179721, 3167, 162584, 2681, 429, 21502, 369, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"b2621b3d-93f0-42a4-80a5-392408c50b51"]
}, Open  ]],
Cell[CellGroupData[{
Cell[342342, 5853, 1562, 35, 126, "Input",ExpressionUUID->"cfdf2ccd-5480-4654-a5e1-dd899115f1ee"],
Cell[343907, 5890, 4291, 88, 492, "Output",ExpressionUUID->"9e44e956-07eb-4224-a439-4556dbe59e55"],
Cell[348201, 5980, 4642, 97, 492, "Output",ExpressionUUID->"1079b784-2f10-4fd5-8200-5268d0fd873b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[352880, 6082, 1124, 26, 63, "Input",ExpressionUUID->"211e599f-a938-4678-aa9a-3aa21e111218"],
Cell[354007, 6110, 27740, 505, 506, "Output",ExpressionUUID->"c7319d43-21bd-4da8-96f9-3790452e4ee2"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

